#
# spec file for package poppler
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%global sname poppler
%if "%{flavor}" == ""
%else
%global psuffix -%{flavor}
%endif
# Actual version of poppler-data:
%define poppler_data_version 0.4.11
%define poppler_sover 145
%define poppler_cpp_sover 2
%define poppler_glib_sover 8
%define poppler_qt5_sover 1
%define poppler_qt6_sover 3
%define poppler_api 0.18
%define poppler_apipkg 0_18
Name:           poppler%{?psuffix}
Version:        25.01.0
Release:        1.1
Summary:        PDF Rendering Library
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://poppler.freedesktop.org
Source:         %{url}/%{sname}-%{version}.tar.xz
Source1:        %{url}/%{sname}-%{version}.tar.xz.sig
Source90:       poppler.keyring
Source99:       baselibs.conf
Patch0:         reduce-boost-required-version.patch
Patch1:         reduce-libtiff-required-version.patch

BuildRequires:  cmake >= 3.10
BuildRequires:  gtk-doc
BuildRequires:  libboost_headers-devel >= 1.66
BuildRequires:  libgpgmepp-devel >= 1.19
BuildRequires:  openjpeg2
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(cairo-ft)
BuildRequires:  pkgconfig(cairo-pdf)
BuildRequires:  pkgconfig(cairo-ps)
BuildRequires:  pkgconfig(cairo-svg)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2) >= 24.0.18
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.36
BuildRequires:  pkgconfig(glib-2.0) >= 2.56
BuildRequires:  pkgconfig(gobject-2.0) >= 2.41
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(poppler-data)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} < 1550
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif
%if 0%{?sle_version} >= 150300
BuildRequires:  extra-cmake-modules
%endif
# Don't build poppler-qt6 on Leap <= 15.3
%if "%{flavor}" == "qt6" && (0%{?suse_version} <= 1500 && 0%{?sle_version} <= 150300)
ExclusiveArch:  do_not_build
%endif
%if "%{flavor}" == "qt5"
BuildRequires:  pkgconfig(Qt5Core) >= 5.9
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
%endif
%if "%{flavor}" == "qt6"
BuildRequires:  cmake(Qt6Core) >= 6.1
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
%endif

%description
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler%{poppler_sover}
Summary:        PDF Rendering Library
Group:          System/Libraries
Recommends:     ghostscript-fonts-std
Recommends:     poppler-data >= %{poppler_data_version}

%description -n libpoppler%{poppler_sover}
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler-cpp%{poppler_cpp_sover}
Summary:        C++ API of the Poppler PDF rendering library
Group:          System/Libraries

%description -n libpoppler-cpp%{poppler_cpp_sover}
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler-glib%{poppler_glib_sover}
Summary:        Glib wrapper for the poppler PDF rendering library
Group:          System/Libraries
Requires:       libpoppler%{poppler_sover} >= %{version}

%description -n libpoppler-glib%{poppler_glib_sover}
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     typelib-1_0-Poppler-%{poppler_apipkg}
Summary:        Introspection bindings for the Poppler PDF rendering library
Group:          System/Libraries

%description -n typelib-1_0-Poppler-%{poppler_apipkg}
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

This package provides the GObject Introspection bindings for Poppler.

%package -n     libpoppler-qt5-%{poppler_qt5_sover}
Summary:        Qt5 wrapper for the Poppler PDF rendering library
Group:          System/Libraries
Requires:       libpoppler%{poppler_sover} >= %{version}

%description -n libpoppler-qt5-%{poppler_qt5_sover}
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler-qt6-%{poppler_qt6_sover}
Summary:        Qt6 wrapper for the Poppler PDF rendering library
Group:          System/Libraries
Requires:       libpoppler%{poppler_sover} >= %{version}

%description -n libpoppler-qt6-%{poppler_qt6_sover}
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package        tools
Summary:        PDF Rendering Library Tools
Group:          Productivity/Publishing/PDF
Requires:       libpoppler%{poppler_sover} >= %{version}
Provides:       pdfattach = %{version}
Provides:       pdfdetach = %{version}
Provides:       pdffonts = %{version}
Provides:       pdfimages = %{version}
Provides:       pdfinfo = %{version}
Provides:       pdfseparate = %{version}
Provides:       pdfsig = %{version}
Provides:       pdftocairo = %{version}
Provides:       pdftohtml = %{version}
Provides:       pdftoppm = %{version}
Provides:       pdftops = %{version}
Provides:       pdftotext = %{version}
Provides:       pdfunite = %{version}

%description    tools
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler-devel
Summary:        Development files for the Poppler PDF rendering library
Group:          Development/Libraries/C and C++
Requires:       libboost_headers-devel >= 1.66
Requires:       libpoppler%{poppler_sover} = %{version}
Requires:       libpoppler-cpp%{poppler_cpp_sover} = %{version}
Requires:       libstdc++-devel

%description -n libpoppler-devel
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler-glib-devel
Summary:        Development files for the Poppler Glib wrapper library
Group:          Development/Libraries/C and C++
Requires:       libpoppler-glib%{poppler_glib_sover} = %{version}
Requires:       typelib-1_0-Poppler-%{poppler_apipkg} = %{version}

%description -n libpoppler-glib-devel
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler-qt5-devel
Summary:        Development files for the Poppler Qt5 wrapper library
Group:          Development/Libraries/C and C++
Requires:       libpoppler-devel = %{version}
Requires:       libpoppler-qt5-%{poppler_qt5_sover} = %{version}
Requires:       pkgconfig(Qt5Core)
Requires:       pkgconfig(Qt5Gui)
Requires:       pkgconfig(Qt5Widgets)
Requires:       pkgconfig(Qt5Xml)

%description -n libpoppler-qt5-devel
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%package -n     libpoppler-qt6-devel
Summary:        Development files for the Poppler Qt6 wrapper library
Group:          Development/Libraries/C and C++
Requires:       libpoppler-devel = %{version}
Requires:       libpoppler-qt6-%{poppler_qt6_sover} = %{version}
Requires:       cmake(Qt6Core)
Requires:       cmake(Qt6Gui)
Requires:       cmake(Qt6Widgets)

%description -n libpoppler-qt6-devel
Poppler is a PDF rendering library, forked from the xpdf PDF viewer
developed by Derek Noonburg of Glyph and Cog, LLC.

%prep
%autosetup -p1 -n poppler-%{version}

%build
%if "%{flavor}" == "qt5"
export MOCQT5='%{_libqt5_bindir}/moc'
export MOCQT52='%{_libqt5_bindir}/moc'
%endif
%if 0%{?suse_version} < 1550
export CXX=g++-12
%endif

# make introspection scanner (g-ir-scanner) work with older build envs
export LD_LIBRARY_PATH=$(pwd)/build
%cmake \
	-DENABLE_GTK_DOC=ON \
	-DENABLE_GPGME=ON \
	-DENABLE_UNSTABLE_API_ABI_HEADERS=ON \
	-DENABLE_ZLIB=ON \
	-DENABLE_LIBCURL=ON \
	-DBUILD_GTK_TESTS=OFF \
%if "%{flavor}" == ""
        -DENABLE_QT5=OFF \
        -DENABLE_QT6=OFF \
%endif
%if "%{flavor}" == "qt5"
	-DENABLE_QT5=ON \
	-DENABLE_QT6=OFF \
	-DENABLE_GLIB=OFF \
	-DENABLE_CPP=OFF \
%endif
%if "%{flavor}" == "qt6"
	-DENABLE_QT6=ON \
	-DENABLE_QT5=OFF \
	-DENABLE_GLIB=OFF \
	-DENABLE_CPP=OFF \
%endif
	%{nil}

%cmake_build

%install
%cmake_install
%if "%{flavor}" == "qt5" || "%{flavor}" == "qt6"
cd %{buildroot} && find . -type f -o -type l | grep -v qt | xargs rm -v
%endif

%if "%{flavor}" == ""
%find_lang pdfsig %name-tools.lang
%endif

echo > %{SOURCE99}
%if "%{flavor}" == "qt5"
echo "libpoppler-qt5-%{poppler_qt5_sover}" >> %{SOURCE99}
%else
echo "libpoppler%{poppler_sover}" >> %{SOURCE99}
echo "libpoppler-glib%{poppler_glib_sover}" >> %{SOURCE99}
echo "libpoppler-cpp%{poppler_cpp_sover}" >> %{SOURCE99}
%endif

%post -n libpoppler%{poppler_sover} -p /sbin/ldconfig
%postun -n libpoppler%{poppler_sover} -p /sbin/ldconfig
%post -n libpoppler-glib%{poppler_glib_sover} -p /sbin/ldconfig
%postun -n libpoppler-glib%{poppler_glib_sover} -p /sbin/ldconfig
%post -n libpoppler-cpp%{poppler_cpp_sover} -p /sbin/ldconfig
%postun -n libpoppler-cpp%{poppler_cpp_sover} -p /sbin/ldconfig
%post -n libpoppler-qt5-%{poppler_qt5_sover} -p /sbin/ldconfig
%postun -n libpoppler-qt5-%{poppler_qt5_sover} -p /sbin/ldconfig
%post -n libpoppler-qt6-%{poppler_qt6_sover} -p /sbin/ldconfig
%postun -n libpoppler-qt6-%{poppler_qt6_sover} -p /sbin/ldconfig

%if "%{flavor}" == "qt5"
%files -n libpoppler-qt5-%{poppler_qt5_sover}
%{_libdir}/libpoppler-qt5.so.%{poppler_qt5_sover}*

%files -n libpoppler-qt5-devel
%dir %{_includedir}/poppler
%{_includedir}/poppler/qt5
%{_libdir}/libpoppler-qt5.so
%{_libdir}/pkgconfig/poppler-qt5.pc

%else
%if "%{flavor}" == "qt6"
%files -n libpoppler-qt6-%{poppler_qt6_sover}
%{_libdir}/libpoppler-qt6.so.%{poppler_qt6_sover}*

%files -n libpoppler-qt6-devel
%dir %{_includedir}/poppler
%{_includedir}/poppler/qt6
%{_libdir}/libpoppler-qt6.so
%{_libdir}/pkgconfig/poppler-qt6.pc

%else

%files -n libpoppler%{poppler_sover}
%license COPYING COPYING3
%doc NEWS README.md README-XPDF
%{_libdir}/libpoppler.so.%{poppler_sover}*

%files -n libpoppler-glib%{poppler_glib_sover}
%{_libdir}/libpoppler-glib.so.%{poppler_glib_sover}*

%files -n typelib-1_0-Poppler-%{poppler_apipkg}
%{_libdir}/girepository-1.0/Poppler-%{poppler_api}.typelib

%files tools -f %name-tools.lang
%license COPYING COPYING3
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}

%files -n libpoppler-cpp%{poppler_cpp_sover}
%{_libdir}/libpoppler-cpp.so.%{poppler_cpp_sover}*

%files -n libpoppler-devel
%doc AUTHORS NEWS README.contributors
%{_includedir}/poppler
%exclude %{_includedir}/poppler/glib
%{_libdir}/libpoppler.so
%{_libdir}/libpoppler-cpp.so
%{_libdir}/pkgconfig/poppler.pc
%{_libdir}/pkgconfig/poppler-cpp.pc

%files -n libpoppler-glib-devel
%{_includedir}/poppler/glib
%{_libdir}/libpoppler-glib.so
%{_libdir}/pkgconfig/poppler-glib.pc
%{_datadir}/gir-1.0/Poppler-%{poppler_api}.gir
%doc %{_datadir}/gtk-doc/html/poppler

%endif
%endif

%changelog
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 25.01.0:
  + core:
  - TextOutputDev: Better detect fakebold words
  - TextOutputDev: Faster sorting algorithm
  - Internal code improvements
  - Fix crashes in malformed documents
  + cpp: Remove rect parameter from image::copy, it was never
    implemented
  + qt6: Fix crash in Submit Forms if document links to non
    existing field
  + qt5: Fix crash in Submit Forms if document links to non
    existing field
  + glib: mark transfer of poppler_page_get_selected_region
  + utils: pdfdetach: Make -savefile work with Unicode strings.
  + build system: Don't update pdfsig.pot when POT-Creation-date is
    the only change.
- Drop poppler-CVE-2024-56378.patch: Fixed upstream.
- Bump poppler sover and poppler_cpp_sover following upstream
  changes.
* Mon Dec 23 2024 pgajdos@suse.com
- Security update:
  + Added patch; fix CVE-2024-56378 [bsc#1234795], out-of-bounds
    read vulnerability within the JBIG2Bitmap::combine function in
    JBIG2Stream.cc (poppler-CVE-2024-56378.patch)
* Thu Dec 19 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 24.12.0:
  + core:
  - cairo:
    . Fix rendering of JPX images with transparency
    . Fix JPX transparency regression
  - Override encoding for Zapf Dingbats
  - Improve Signature appearance generation code
  - Improve Stamp appearance generation code
  - Mark certificates that can do qualified signing
  - Internal code improvements
  + qt6: Mark certificates that can do qualified signing
  + glib: Add free text annotations support
  + utils: pdfsig: Improve man page
  + build system:
  - Install some more internal headers
  - Fix build with in-tree build
- For changes between 24.07 and this release, please see NEWS file.
- Bump sover following upstream changes.
- Rebase patches with quilt.
* Tue Sep 17 2024 Antonio Larrosa <alarrosa@suse.com>
- Poppler can load ghostscript fonts (n022003l.pfb and the like)
  so the package now recommends the ghostscript-fonts-std package
  (boo#1230636).
* Sat Aug  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add Provides for binaries in poppler-tools package
* Tue Jul  2 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Use correct version for freetype BuildRequires.
* Tue Jul  2 2024 Dirk Müller <dmueller@suse.com>
- update to 24.07.0:
  core:
  * Fix crashes in broken files
  * Internal code improvements
  qt6:
  * Add getters for document additional actions
  * Implement reset forms link
  qt5:
  * Add getters for document additional actions
  * Implement reset forms link
  utils:
  * pdfinfo: Fix crash in broken documents when using -dests
  build system:
  * Mark glib-mkenums as required
- drop poppler-CVE-2024-6239.patch (upstream)
* Tue Jun 25 2024 pgajdos@suse.com
- version update to 24.06.1
  Release 24.06.1:
  Re-release 24.06.0 with increased SOVERSION of poppler internal library
  Release 24.06.0:
  core:
  * Performance improvements in some files
  * Fix some issues with files bigger than 2^31 bytes
  * Remove all cairo include guards for cairo < 1.16
  * Fix MSVC build
  * Internal code improvements
  qt6:
  * Update Qt6 doc example
  * Use the non deprecated version of QString::fromUcs4
  glib:
  * properly document return value from poppler_font_info_scan
  Release 24.05.0:
  core:
  * Fix signing not being totally correct in some kind of PDF files
  * Assume "Adobe-Identity" for character collection. Issue #1465
  * Small improvements in annotation font rendering
  * Remove some GooString methods, use std::string ones instead
  * Move some GooString methods to UTF.h
  * Fix crash in broken files
  cpp:
  * cpp: Fix crash extracting text and font in some files. Issue #1477
  * Change base class of ustring to char16_t
  qt6:
  * Add async API for certificate validation
  * Fix text extraction for Landscape/Seascape pages
  qt5:
  * Add async API for certificate validation
  * Fix text extraction for Landscape/Seascape pages
  utils:
  * pdfdetach: Small code improvements
  * pdftops: Write compliant ps header
  build system:
  * Increase minimum supported base to that provided by Ubuntu 22.04
  Release 24.04.0:
  core:
  * Optimize page text extraction speed
  * Fix clipping path handling in some files. Issue #739
  * Fix regression in text selection
  * Fix text search across lines between paragraphs
  qt6:
  * Fix crash in SoundObject::data
  utils:
  * pdfsig: Add Catalan translation
  build system:
  * Build code as C++20
- modified patches
  %% reduce-boost-required-version.patch (refreshed)
  %% reduce-libtiff-required-version.patch (refreshed)
- added patches
  fix CVE-2024-6239 [bsc#1226916], crash when using pdfinfo with -dests parameter on malformed input files
  + poppler-CVE-2024-6239.patch
* Mon Mar  4 2024 Antonio Larrosa <alarrosa@suse.com>
- version update to 24.03.0
  Release 24.03.0:
  core:
  * Fix opening some malformed files. Issue #1447
  * Skip drawing image when it has singular matrix. Issue #1114
  * Fix crash on malformed files
  * Small internal code cleanup
  utils:
  * pdfdetach: Fix potential directory traversal
  * pdfimages: Enable to print filenames to stdout.
  * pdfsig: Add visible name/date when signing an existing form
    signature field
- Bump poppler_sover to 135 following upstream changes.
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Feb 14 2024 pgajdos@suse.com
- version update to 24.02.0
  Release 24.02.0:
  core:
  * Fix reading some JBIG2 streams. Issue #1319
  * Fix saving some annotation interior color when it's empty
  * Make searching for fonts when adding annotations a bit faster
  * Make sure images are compressed when adding them
  * Small internal code cleanup
  utils:
  * pdfimages: return exit code 2 when error opening output files
  Release 24.01.0:
  core:
  * Don't crash on certain documents on the NSS signature backend
  * Fix infinite loop in some annotation code if there's not space for even one character
  * Fix build on Android with generic font configuration
  * Small internal code cleanup
* Tue Dec 26 2023 Antonio Larrosa <alarrosa@suse.com>
- version update to 23.12.0
    core:
  * Rewrite FoFiType1::parse to be more flexible
  * Small internal code refactoring
* Thu Nov 16 2023 pgajdos@suse.com
- version update to 23.11.0
    core:
  * CairoOutputDev: Use internal downscaling algorithm if image exceeds Cairo's maximum dimensions.
  * Internal code improvements
  * Fix crash on malformed files
    utils:
  * pdftocairo: Add option to document logical structure if output is pdf
  * pdftocairo: EPS output should not contain %%%%PageOrientation
* Mon Oct 30 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to let it build with the heavily patched tiff 4.0.9
  we have in SLE 15:
  * reduce-libtiff-required-version.patch
* Fri Oct 27 2023 pgajdos@suse.com
- version update to 23.10.0
    core:
  * cairo: update type 3 fonts for cairo 1.18 api
  * Fix crash on malformed files
    build system:
  * Make a few more dependencies soft-mandatory
  * Add more supported gnupg releases
  * Check if linker supports version scripts
- modified patches
  %% reduce-boost-required-version.patch (refreshed)
* Fri Sep 29 2023 Dirk Müller <dmueller@suse.com>
- build with gpgmepp for signing documents (bsc#1215632)
* Tue Sep 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 23.09.0:
  * core:
  - Add Android-specific font matching functionality
  - Fix digital signatures for NeedAppearance=true
  - Forms: Don't look up same glyph multiple times
  - Provide the key location for certificates you can sign with
  - Add ToUnicode support for similarequal
  - Fix crash on malformed files
  * qt5:
  - Provide the key location for certificates you can sign with
  - Allow to force a rasterized overprint preview during PS
    conversion
  * qt6:
  - Provide the key location for certificates you can sign with
  - Allow to force a rasterized overprint preview during PS
    conversion
  * pdfsig:
  - Provide the key location for certificates you can sign with
- Changes from version 23.08.0:
  * core:
  - Fix GWG 19.2 - DeviceN Overprint (White)
  - Splash: avoid bogus memory allocation size in
    doTilingPatternFill
  - Fix use-of-uninitialized-value in XRef
  - Fix float-cast-overflow error in Catalog
  - Cleanup gpgme backend code
  - Version symbols in poppler core
  * glib:
  - Improve poppler_get_available_signing_certificates
  - Add new members to PopplerCertificateInfo
  * utils:
  - pdftotext: small improvement to man page
- Bump poppler_sover to 131 following upstream changes.
* Sat Jul 15 2023 Dirk Müller <dmueller@suse.com>
- update to 23.07.0:
  core:
  * Fix reading of utf8-with-bom files
  * Fix crash if CERT_ExtractPublicKey doesn't return a public
    key
  * Fix rendering of some malformed documents. Issue #1395
  * Allow for stream compression and compress font streams in
    forms Remove method Hints::getPageRanges
  qt5:
  * Fix crash when overprint preview is enabled
  * Don't fail signature basics tests if backend is not
    configured
  qt6:
  * Fix crash when overprint preview is enabled
  * Don't fail signature basics tests if backend is not
    configured
  utils:
  * pdfsig: Allow showung and selecting signature backend
  * pdfsig: Describe signature dump format in manual page
* Tue Jun 13 2023 Dirk Müller <dmueller@suse.com>
- update to 23.06.0 (bsc#1212255):
  * CairoOutputDev: Fix crash when doing type3 rendering
  * Fix crash with unknown signature hashing algorithms
  * Add gpgme backend for signature handling
  * FontInfo: Make it return proper information about font
    substitution
  * FontInfo: Try harder to get Type 3 font name
  * Store embedded fonts widths table in a more effective manner
  * Skip font lookup for nonprintable characters
  * Fix crash on malformed files
  * Add API to allow selecting signature backend (nss or gpgme)
  * Convert embedded files to bytearray a bit smarter
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- update to 23.05.0:
  * Fix crash when filling some forms
  * Set SigFlags when signing unsigned signature
  * Add some infrastructure code to support multiple signing
    backends
  * Fix potential stack overflow in PostScriptFunction::parseCode
  * Fix some minor uninitialised memory reads
* Mon Apr  3 2023 Dirk Müller <dmueller@suse.com>
- update to 23.04.0:
  * Fix memory issue when signing fails. Issue #1372
  * Internal improvements of signature related code
  * CairoOutputDev: improve type3 font rendering
  * Fix memory leak in
    GlobalParams::findSystemFontFileForFamilyAndStyle
  * pdftocairo: Fix crash in some special situations
  * pdfsig: allow holes in -dump signature list
  * pdfsig: Support --help
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 23.03.0:
  core:
  * PngWriter: Fix potential uninitialized memory use
* Wed Feb 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 23.02.0:
  + core:
  * CairoOutputDev:
    . Fix rendering of color type 3 fonts
    . Add handling matte entry
  * Fix segfault on wrong nssdir
  * Fix "NSS could not shutdown"
  + utils: pdfsig: Point out supports PKCS#11 URIs as nickname
* Thu Jan 12 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to reduce the boost dependencies (which isn't really
  needed) so we can build poppler 23.01.0 in SLE-15-SP4/SP5:
  * reduce-boost-required-version.patch
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 23.01.0:
  core:
  * PDFDoc::sign: Fix crash if font can't be found
  * PDFDoc::sign: Try Arial to sign if Helvetica isn't found
  * FoFiType1::parse: Be more flexible parsing the encoding content. Issue #1324
  * Gfx::opBeginMarkedContent: Support Span with Name. Issue #1327
  * Splash: Avoid color issues due to implicit rounding
  * Splash: Fix crash on malformed file.
  * CairoOutputDev: Ignore text rendering mode for type3 fonts
  * Remove unused FoFiType1::load function
  build system:
  * Increase minimum required versions of several dependencies
  * Improve include path handling
  qt6:
  * Use less deprecated functions
* Fri Dec  9 2022 Peter Simons <psimons@suse.com>
- Configure $CXX to the correct compiler version on codestreams
  that have gcc12, such as SLE-15-SP5. [bsc#1206019]
* Mon Dec  5 2022 Stefan Weiberg <sweiberg@suse.com>
- The development compiler in SLE 15 has been updated to gcc12 via
  maintenance update. Therefore adjusting the compiler version for
  SLE 15 in the spec file, to not build with gcc11 anymore. This
  resolves bsc#1206019.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 22.12.0:
  core:
  * Form::addFontToDefaultResources: Be stubborn in finding a font we can use. Issue #1272
* Thu Nov 17 2022 Dirk Müller <dmueller@suse.com>
- update to 22.11.0:
  core:
  * CairoOutputDev: Update font after restore
  * Protect against broken files
  * Small code refactoring
* Tue Oct  4 2022 Dirk Müller <dmueller@suse.com>
- update to 22.10.0:
  * SplashOutputDev::tilingPatternFill: Properly restore CTM on failure.
  * Protect against malformed files
  * Refactor code to not use strndup
  * Other small code refactoring
  utils:
  * pdftoppm: Avoid round-off errors when determining raster dimensions
  * pdftocairo: Avoid round-off errors when determining raster dimensions
  * pdftotext: Simplify memory handling
  qt:
  * Take into account flagNoView when getting/setting the visible status.
    KDE bug #456313
* Mon Sep 12 2022 Dirk Müller <dmueller@suse.com>
- update to 22.09.0 (CVE-2022-38784):
  * Splash: Do not truncate line dash patterns with more than 20 entries. Issue #1281
  * Various signature related improvements
  * Fix FormField::getFullyQualifiedName in some scenarios
  * Splash: Small optimization on dash pattern handling
  * JBIG2Stream::readHalftoneRegionSeg: Fix potential memory leak
  * Fix crashes on malformed files. Including CVE-2022-38784
  * Fix string formatting in error reporting
  * Fix two potential memory leaks in poppler_document_create_dests_tree
  * pdfsig: List signature field names when listing signature information
  * pdfsig: Add support for specifying signature by field name
  * pdfunite: Fix crashes on malformed files
  * pdfunite: Fix potential memory leak of docs
- Bump soname following upstreams changes.
* Tue Aug  2 2022 Dirk Müller <dmueller@suse.com>
- update to 22.08.0:
  * Fix rendering text on some forms
  * CairoOutputDev: Support Type3 charprocs having Resources
  * Fix crashes on malformed files
* Mon Jul 25 2022 Dirk Müller <dmueller@suse.com>
- update to 22.07.0:
  * Fix crash when filling in forms in some files. Issue #1258
  * Fix first lines of Annotations sometimes being cut off. Issue #1246
  * Signatures: Don't crash if the signature doesn't have a common name
  * CairoFontEngine: increment font_face reference when retrieving from the cache
  * Add ToUnicode support for lessorequalslant and greaterorequalslant
  glib:
  * Add support for stamp annotation
- add gpg keyring validation for the release tarball
- drop da226d346e691f7545d995d6761d43e08855a3b7.patch (upstream)
* Sat Jul 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add da226d346e691f7545d995d6761d43e08855a3b7.patch --
  CairoFontEnginer: increment font_face reference when retrieving
  from the cache; this fixes crashes with certain pdfs
  [glgo#GNOME/evince#1808, glfo#poppler/poppler#1212].
* Sun Jun  5 2022 Dirk Müller <dmueller@suse.com>
- update to 22.06.0:
  core:
  * Forms: Fix crash in forms with their own DR
  * Refactor CairoFontEngine caching
  * CairoOutputDev: preserve text color when drawing type 3 glyphs
  * Windows: font code simplification
  * Minor code improvements
  * pdfattach: Assume filename is utf8 encoded
  * pdftohtml: Fix type 3 font size calculation
- drop poppler-cairo_font_face_t-incorrect-cacheing.patch (upstream)
* Sat May 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add poppler-cairo_font_face_t-incorrect-cacheing.patch -- Fix
  missing symbols after reloading some pdf files; patch taken from
  upstream merge request [glfo#poppler/poppler#1247].
* Sat May  7 2022 Dirk Müller <dmueller@suse.com>
- update to 22.05.0:
  * Annotations: Make sure we embed fonts for the FreeText annots
  * Forms: Make sure we embedd fonts as needed
  * Signatures: Make sure we embed the needed fonts
  * CairoOutputDev: color type 3 fonts
  * fix two bugs in multiline find_text()
  * code improvements
  * pdftotext: added TSV mode
  * HtmlOutputDev: don't use png.h
  * Use time_t for time
  * Add page_transition::durationReal
  * Pass leftFontSize down to `FormWidgetSignature::signDocumentWithAppearence`
* Tue Apr 19 2022 Dirk Müller <dmueller@suse.com>
- update to 22.04.0:
  * Fix underline sometimes being drawn only partially
  * Fix Adobe Reader not reading some of the contents we write correctly
  * Fix code that workarounds some broken-ish files
  * FoFiTrueType: Parse CFF2 fonts too
  * FoFiTrueType: Support cmap types 2 and 13
  * Fix a few small memory leaks
  * code improvements
  qt:
  * Handle SaveAs named action
  * Annotations: don't change the text color when changing the font
  utils:
  * pdftotext: print creation and modification date when using htmlmeta param
  glib:
  * Fix returning internal data of temporary strings
  cpp:
  * Fix code incompatibility with MSVC
  build system:
  * poppler internal library is no longer forced to static on MSVC
  * Error out if iconv is not available and the cpp frontend is enabled
  * Require FreeType 2.8
* Thu Mar  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 22.03.0:
  + core:
  - Signature:
    . Fix finding Signatures that are in Pages not not in the
    global the Forms object
    . Improve getting the path to the firefox certificate
    database
  - Splash: Fix rendering of some joints.
  - Fix get_poppler_localdir for relocatable Windows builds
  - Minor code improvements
  + qt: Minor code improvements
  + utils: pdfimages: Fix the wrong Stream being passed for
    drawMaskedImage
  + build system: Small code improvements
- Changes from version 22.02.0:
  + core:
  - Signature:
    . Add a way to detect unsigned FormFieldSignature
    . Suport background image when using left and right text
    . Fix path where to search for Firefox NSS in Windows
    . Fix NSS code to work correctly in Windows/Android
  - Count only signature fields in PDFDoc::getNumSignatureFields
  - Minor code improvements
  + qt:
  - Allow signing unsigned signature fields
  - Allow passing a background image for the signature when
    signing
  - Allow passing the document password when signing
  - Fix leftFontSize being ignored when signing
  + glib:
  - Try with utf8 password if latin1 fails
  - New method for getting all signature fields of a document
  - Fix compile with MSVC
  + utils: pdfsig: Fix compile with MSVC
  + build system: Fix NSS cmake check for MSVC
- Bump poppler sover following upstream changes.
* Tue Jan 11 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to 22.01.0:
  core:
  * Allow local (relative to dll) fonts dir on Windows
  * TextOutputDev: require more spacing between columns.
    Issue #1093
  * Fix crash in Splash::gouraudTriangleShadedFill. Issue #1183
  * Fix crash when calling Form::reset()
  * GfxSeparationColorSpace: Check validity of colorspace and
    function. Issue #1184
  * Minor code improvements
  glib:
  * Include glib.h before using defines from it
  * Close file descriptors on error
  * Plug some memory leaks
  * Replace use of deprecated g_memdup/g_time_zone_new
  * Remove FD-taking functions on windows
  utils:
  * pdfsig: Add support for documents with passwords
  * pdfsig: Fix signing with -sign if nss password is needed
* Wed Dec 22 2021 Antonio Larrosa <alarrosa@suse.com>
- Use gcc11 when building in SLE/Leap since a Qt6 header file
  includes <filesystem> which was still experimental in gcc7.
* Thu Dec  2 2021 Dirk Müller <dmueller@suse.com>
- update to 21.12.0:
  * Add API to add images
  * CairoOutputDev: Fix de-duping of Flate images
  * Fix crash on broken files when using non-default ENABLE_ZLIB_UNCOMPRESS. Issue #393
  * Minor code improvements
  * Add API for validation of signatures
  * Add API to read/save to file descriptor
  * pdftohtml: Reduce sensitivity of duplicate detection. Issue #1117
  * Increase C++ standard to 17
* Wed Nov 10 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 21.11.0:
  core:
  * Fix rendering of some non-standard confirming annotations
  * Support rendering of some non-standard Type3 charprocs
  * TextOutputDev: Respect orientation when selecting words
  * CairoOutputDev: Don't override the antialias settings from the cairo_t
  * StructElement: support MCID in XObjects
  * Fix detection of monospace fonts
  * Ignore Adobe-Identity for non embedded CID fonts
  * PageLabelInfo::labelToIndex: work on some special no style intervals
  * Fix crash in malformed files
  * Minor code improvements
  utils:
  * pdfinfo: add -url option to print all URLs in a PDF
  * pdftohtml: document what zoom means in regard to DPI
  qt6:
  * Require Qt 6.1
  * Minor code improvements
* Fri Oct  1 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 21.10.0:
  core:
  * Add support for setting custom stamp annotations
  * Add default appearance for the well known stamp names
  * Correct encoding of signature's properties Reason & Location
  * Splash: Fix rendering of some odd patterns
  * SignatureHandler::validateCertificate: Add option to not do OCSP revocation check
  * SignatureHandler::validateCertificate: Add support for AIA fetching to verify certificates
  * greallocn: if memory allocation fails, free the previous pointer to avoid memory leak
  * Fix issues with malformed files
  utils:
  * pdfsig: Add a way to list certificate nicknames
  * pdfsig: You can now add signatures from pdfsig
  * pdfsig: Add option to not do OCSP revocation check
  * pdfsig: Add option for AIA fetching to verify certificates
  * pdfinfo: Add -custom option to print custom metadata
  * pdfinfo: add metadata flags
  qt:
  * Add support for setting custom stamp annotations
  * Add getters for signature's properties Reason & Location
  glib:
  * Remove incorrect PopplerAttachment deprecation
* Mon Sep 27 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 21.09.0:
  core:
  * Splash: Massive speed improvement on files that use lots of save/restore (q/Q) operators
  * Correct decoding of signature properties Reason & Location when they are Unicode
  * Fix issues with malformed files
* Sat Aug  7 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 21.08.0:
  core:
  * Add API to allow addition and modification of outlines into a PDF
  * Use additional samples to test for constant parts of an axial gradient
  * forms: Create fallback fonts for some well known font names
  * Support reading the PDF Version from the Catalog
  * Fix XRef::copy when there are modified objects
  * Take into account that Date string may be in unicode
  * JBIG2Stream: Fix regression in "Do not consider a size-0 to be an error"
  * Replace a local bubble sort implementation by std::sort
  * Fix issues with malformed files
  build system:
  * Better error message when libjpeg is not found
  * Better error messages when libopenjpeg2 is not found
  qt5/qt6:
  * Document that a document has to outlive its pages
  * Make getPdfVersion return a dedicated version object
  glib:
  * mimick TextSelectionDumper logic change for spaceAfter
* Mon Jul 26 2021 Dirk Müller <dmueller@suse.com>
- update to 21.07.0:
  core:
  * JBIG2Stream: Do not consider a size-0 to be an error. Issue #535
  * PSOutputDev: fix off-by-one error for image masking in L1/L2 output. Issue #1088
  * CairoOutputDev: Fix memory leak on broken files
  * Minor code improvements
  build system:
  * set C standard to 11 without extensions
* Sat Jun 19 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 21.06.1:
  core:
  * Fix rendering of some extended latin1 characters in annotations. Issue #1070
  * Support some not so well formed documents with password. Issue #1083
  * Add API to get notified if the xref is reconstructed
  * Add somewhat fancier left/right signature visual representation
  * Fix crashes in malformed files
  * Minor code improvements
  qt6:
  * Change some functions to return std::unique_ptr
  qt5/qt6:
  * Add API to get notified if the xref is reconstructed
  * Add somewhat fancier left/right signature visual representation
  * Don't assert when trying to invert singular matrices
  build system:
  * make boost opt-out if building splash
  glib:
  * fix poppler_rectangle_free() regression. Issue #1087
* Tue May  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 21.05.0:
  core:
  * Fix crashes in malformed files
  * Export SplashFont* symbols used by Scribus
  * Minor code improvements
  glib:
  * Enhance find to support multi-line matching
  qt5/qt6:
  * Make sure new signatures are always properly oriented
  * Allow to pass the border width when signing
  utils:
  * pdftoppm: Fix regression when using single scaleTo.
- Drop Export-SplashFont-symbols-used-by-Scribus.patch as the change
  was upstreamed
* Mon Apr 26 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add Export-SplashFont-symbols-used-by-Scribus.patch to fix
  scribus' PDF import plugin
* Sun Apr  4 2021 Axel Braun <axel.braun@gmx.de>
- update to 21.04.0
  core:
  * Hide symbols by default
  * TextSelectionDumper: fix word order for RTL text
  * Fix rendering of text in some files. Issue #1052
  * Implement rendering of Masks of Image subtype. Issue #1058
  * Forms: fix unclicking standalone form buttons. Issue #1034
  glib:
  * Expose more fields from MediaRendition in PopplerMedia
  * Use stock glib macro to define boxed type
  * Remove incorrecly used volatile from enum type registration code
  qt5:
  * Fix crash in files with malformed signatures
  * Fix memory leak when QImage constructor "fails"
  qt6:
  * Fix crash in files with malformed signatures
  * Fix memory leak when QImage constructor "fails"
  utils:
  * pdfsig: New paragraph for "-sign" in manpage
  * pdfimages: Do not assert in "too big images". Issue #1061
* Fri Mar 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add a Qt6 flavor to poppler
* Sun Mar 14 2021 Dirk Müller <dmueller@suse.com>
- update to 21.03.0:
  core:
  * Fix parsing text in some broken pdf files. Issue #1040
  * Fix memory issue when using threads. Issue #1050
  * TextSelectionDumper: Fix getText() for space after word
  * Change signature of OutputDev:tilingPatternFill
  * Make PDFDocBuilder return a std::unique_ptr
  * Improve well formed check for shading functions
  * Fix leak in case of fread failing
  * Fix memory leak in broken file in JBIG2Stream::readGenericBitmap
  * PSOutputDev: Fix stack overflow in broken files
  glib:
  * poppler_annot_free_text_get_callout_line: Fix wrong static cast
  * poppler-structure-element: fix memleak
  * Improve documentation
  * demo: keep same visual appearance between displayed and copied text
  utils:
  * pdftotext: Add -cropbox option
  * pdftoppm: Add -progress option
  * pdftoppm: Fix rounding bug in computation of output bitmap size. Issue #927
  qt6:
  * Add missing poppler-qt6.pc.cmake
* Thu Feb 11 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 21.02.0:
  + core:
  - GfxCal*ColorSpace: introduce Bradford transform for chromatic adaptation
  - Fix memory leak if saving the file fails
  - Internal code improvements
  - Fix various issues handling broken files
  - Make checkedAdd work for long long in MSVC
  + qt5:
  - Properly export NewSignatureData class
  - Fix regression in QIODeviceOutStream + MSVC
  + qt6:
  - Properly export NewSignatureData class
  - Fix regression in QIODeviceOutStream + MSVC
  + utils:
  - pdftohtml: Fix error() parameter type
* Mon Jan  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 21.01.0:
  + core:
  - Faster routines for jpeg decoding
  - Fix reading signatures in encrypted files
  - Add white point correction when lcms is used
  - JBIG2Stream: Fix byte counting
  - Fix potential data loss if we try to fetch a non existing Ref after modifying the document
  - Specifically use DeviceGray instead of DefaultGray for softmasks
  - Fix various issues handling broken files
    (including bsc#1181551, glfo#poppler/poppler#1014)
  + utils:
  - pdftocairo: Setmode binary for windows
  - pdfsig: Add hability to digitally sign files
  - pdftoppm: add options to set DeviceGray/DeviceRGB/DeviceCMYK
  - pdftops: add options to set DeviceGray/DeviceRGB/DeviceCMYK
  - pdfimages: Account for rotation in PPI calculation
  + qt5 and qt6:
  - Add hability to digitally sign files
* Thu Dec 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 20.12.1:
  + core:
  - PSOutputDev: fixing regression in the rasterization code.
  - Add missing profile copy operation in
    GfxICCBasedColorSpace::copy()
  - Fix issue in broken files.
  + build system: Use modern CMake linking for Qt and boost.
* Wed Dec  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 20.12.0:
  + core:
  - Draw better circles for circle annotations
  - Fix annotation line width if no appearance stream or style
    are given
  - Tweak rendering of highlight annotations
  - Fix border rendering of some annotations
  - Fix rendering of some files
  - PSOutputDev:
    . provide options to set the rasterization color space and
    ICC profile
    . for splashModeCMYK8 and language level >=2 activate
    overprint emulation
    . use the DeviceN8 bitmap for rasterization with CMYK-output
    + overprint
  - Use the font name without subset tag when querying for a
    system font
  - Splash: Fix wrong x adjustment during clipping
  - Splash: Fix blitImage in uncolored tiling patterns
  - timeToDateString: We forgot the ' after the minutes
  - Move psLevel to PSOutputDev creation
  - Fix several issues in broken files
  + utils:
  - pdftops:
    . provide options to set the rasterization color space and
    ICC profile
    . for splashModeCMYK8 and language level >=2 activate
    overprint emulation
* Tue Oct 27 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use the correct, upstream provided tarball.
* Tue Oct 20 2020 Axel Braun <axel.braun@gmx.de>
- update to version 20.10.0:
  + core:
  - Filter out repeated forms.
  - Implement EmbedStream::reset().
  - CairoOutputDev: evict just font faces owned solely by cache.
  - Splash: Rename Yd to Ydown, Xu to Xup, etc.
  - Splash: fix crash in out-of-memory situation.
  - Fix some undefined behaviour situation with forged files.
  - Compability fix for Forms.
  - Fix fetching of Objects failing in some cases.
  - Fix clearing date in Annot setModified/setDate.
  - TextSelectionPainter: support glyphless fonts.
  - Splash: Don't try read past end of image.
  - avoid abort() on large memory allocation.
  - Fix memory leak on broken files.
  - Fix potential invalid memory read.
  - Small code improvements.
  - Sub-page objects: initialize clip max values considering the
    render resolution.
  - Splash: Set initial line width to 1.
  - Fix stack overflow with specially crafted files.
  - GfxShading: Simplify holding the Function.
  - Splash: Fix x86 + windows asm build.
  - Fix regression on PS conversion..
    Regression only happened on applications that are locale
    enabled i.e. Okular but not pdftops, when using a quite new
    lcms and the user locale uses , as decimal separator instead
    of .
  - Add UTF16LE support to TextStringToUCS4, even if the standard
    clearly says it should be UTF16BE
  + qt5:
  - Document TextAnnotation::inplaceAlign.
  - Make Annotation::setModification/CreationDate work on
    existing annots.
  - Be a bit more stubborn converting dates that come from xml.
  - Clean as many null characters from the end as possible when
    converting strings.
  - Deprecate Document::toc.
  - Deprecate AnnotationUtils.
  + glib:
  - Add accessor functions for PopplerAttachment.
  - Deprecate PopplerAttachment GTime fields.
  - Deprecate PopplerDocument date properties.
  + utils:
  - pdftoppm: report error and exit if output file cannot be
    written.
  - Document that PDF-file can be '-' to read it from stdin.
  + build system:
  - cmake: Modern way to link against libpng, zlib and libtiff.
  - cmake: Remove stray support for lcms1 in pdftocairo.
  + qt6:
  - Add work in progress qt6 port.
* Fri Jul  3 2020 Antonio Larrosa <alarrosa@suse.com>
- update to version 0.90.0
  + core:
  - Color profile tweaks
  - Small signature improvements
  - BBoxOutputDev: Fix calculation when type3 fonts are involved
  - Fix potential crash when reading Forms
  - Fix infinite loop in broken file
  + glib:
  - Fix adding annots in rotated pages
  - Add ability to reset forms
  - Several fixes to the documentation
  + qt5:
  - Make it clear we require Qt 5.5
  - demo: Fix crash on broken files
  - Small documentation improvements
  + utils:
  - pdftoppm: Add option to set display profile
  - pdftops: Add a -rasterize option with values always, never,
    or whenneeded
  + build system:
  - Require cmake 3.5
  - More modern cmake way to link against curl
- Bump poppler_sover following upstream changes.
* Wed Jun  3 2020 Axel Braun <axel.braun@gmx.de>
- update to version 0.89.0
  + core:
  - Add support for ResetForm action
  - Fix crash in PDFDoc::getSignatureFields when there's no Forms
    at all
  - Fix exporting to PS of some files with CID fonts
  - Use ICC profiles in PS output (if new enough lcms is used)
  - Allow almost-singular tiling pattern matrices
  - Fix memory leak when failing to load some fonts
  - CairoOutputDev: Use stroke opacity when clipping to a stroke
    path
  - CairoOutputDev: Fix tiling patterns when pattern cell is too
    far
  + glib: Add poppler_movie_get_aspect
  + cpp: Add the font infos to the text_box object
- Bump poppler_sover following upstream changes.
* Thu Apr 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.88.0:
  + core:
  - Support Widget Annotation Buttons not linked to any Form
  - SplashOuputDev: Use stroking opacity when clipping to a
    stroke path
  - Handle 1 bit RGB images in ICC colorspace
  - Internal code improvements
  + qt5:
  - Add Document::signatures. Returns signatures not attached to
    any page
  - ArthurOutputDev:
    . Fix font hinting
    . Set the opacity when filling with axial gradients
    . Implement the clipToStrokePath method
    . Use stroking opacity when clipping to a stroke path
  + glib:
  - Add poppler_page_get_bounding_box
  - Add poppler_form_field_get_alternate_ui_name
  - Implement rotation for 'flagNoRotate' annots
  + cpp: Add non_raw_non_physical layout for page::text()
  + utils:
  - pdftohtml: Fix noRoundedCoordinates->noroundcoord in man page
  - pdfsig: Show also signatures that aren't attached to any page
- Bump poppler_sover following upstream changes.
* Mon Apr  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.87.0:
  + core:
  - Fix crashes due to inconsistent vtables for Clang builds
  - Fix leak in broken files
  - Internal code improvements
  + qt5:
  - Add option to get form choice for export value
  - ArthurOutputDev: Avoid division by zero in updateLineDash
  + glib: Internal code improvements
  + utils: pdftohtml: Fix memory leak in HtmlOutputDev::getLinkDest
- Bump poppler_sover following upstream changes.
* Sun Mar 29 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add pkgconfig(poppler-data) BuildRequires: New versions of
  poppler-data actually have a .pc file, and we check for it during
  build, so lets add this optional dependency.
- Enable building of gtk-docs again.
* Wed Mar 18 2020 Dirk Mueller <dmueller@suse.com>
- Add missing devel package requires (bsc#1153146).
* Mon Mar  2 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.86.1:
  + core:
  - Fix regression in Browse Link handling.
  - Internal code improvements.
- Bump poppler_sover following upstream changes.
* Sun Mar  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.86.0:
  + core:
  - Fix link content exfiltration attack.
  - Splash: Implement gouraudTriangleShadedFill for some non
    parametrized shadings.
  - Fix case unsensitive search for Old Hungarian, Warang Citi,
    Medefaidrin and Adlam.
  - Internal code improvements.
  + glib:
  - Automatic handle of page's cropbox on annots.
  - Fix memory leak if poppler_document_new_from_file fails.
  - Minor speed optimization on poppler_page_get_annot_mapping.
  + utils:
  - pdfdetach: add 'savefile' option.
  - pdftoppm/pdftocairo: Fix more odd/even mismatch.
  + qt5: Fix loading from iodevice.
- Changes from version 0.85.0:
  + core:
  - Fix case unsensitive search for Deseret and Osage.
  - Fix crash in unicodeToAscii7.
  - CairoOutputDev: make initialisation thread-safe.
  - Fix crash on broken files.
  - Internal code improvements.
  + qt5:
  - Fix FormField::name encoding.
  - Accept UTF-16 uiNames for form fields.
  - Fix search for "complex" characters.
  - Allow to load document from QIODevice.
  + utils:
  - pdftoppm/pdftocairo: Fix -e/-o printing the wrong pages.
  - pdftohtml: Fix issue with the font size sometimes being huge.
  + glib: make the frontend initialization thread safe.
- Bump poppler_sover following upstream changes.
* Wed Jan  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.84.0:
  + core:
  - Fix crash when converting from Unicode to ASCII-7
  - Splash::scaleImageYdXu: Protect against crash if srcWidth is
    too big
  - JBIG2Stream:
    . Fix potential crash in malformed documents
    . Fix leak in reset() if called several times
  - Internal code improvements
  + utils:
  - pdfimages: Add error message if first page is larger then
    number of pages
  - pdfinfo: Improved paper size recognition
  - pdfsig: Fix exit code when dumping signatures
  - pdftocairo: Error out when even/odd selects 0 pages
  - pdftohtml: Fix memory leak
  - pdftoppm:
    . Add an option to scale before rotate
    . Add -hide-annotations option
    . Error out when even/odd selects 0 pages
  - pdftops: Improve -optimizecolorspace
  + qt5: Code cleanups
  + glib: Fix compiler warnings
- Bump poppler_sover following upstream changes.
* Thu Nov 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.83.0:
  + core:
  - Improve when a file is recognized as Linearized.
  - Improve const-ness of the code.
  - Make code a bit more readable/maintanable.
  - Fix uninitialized memory uses in broken files.
  + utils:
  - pdffonts: Make code a bit more readable/maintanable.
  - pdftohtml: Make code a bit more readable/maintanable.
  + qt5:
  - Remove a bunch of unused internal functions.
  - trUtf8 -> tr (less warnings).
  + build system: make-glib-api-docs: switch to python3.
- Bump poppler_sover following upstream changes.
* Wed Oct 30 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.82.0:
  + core:
  - Fix not being able to open some files. Issue #832
  - Fix crashes in malformed files
  - Fix memory leak on broken files
  - Minor performance improvements
  - Minor code improvements
  + glib:
  - Add poppler_document_new_from_bytes
  - PopplerAttachment: Silence deprecation warnings for ctime/mtime
  + build system:
  - pdf-inspector: Support builddir != srcdir
  - Install Cairo* headers if Cairo has been found
- Bump poppler_sover following upstream changes.
- Drop patches already included by upstream:
  + 0001-Include-SplashMath.h-only-where-needed.patch
  + 0002-Move-the-non-trivial-part-of-the-clip-test-to-the-im.patch
* Tue Oct  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Avoid unconditional dependency on boost_headers when using the
  (private) splash headers. Depending on the used classes (e.g.
  SplashXPathScanner), the boost headers may still be needed, add
  + 0001-Include-SplashMath.h-only-where-needed.patch
  + 0002-Move-the-non-trivial-part-of-the-clip-test-to-the-im.patch
* Tue Oct  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Define %%cmake_build for Leap 15.0.
* Thu Sep 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.81.0:
  + core:
  - Splash: Always enable support for CMYK rasterization.
  - CairoOutputDev: Check scaled dimensions for 0.
  - BaseCryptStream: Fix potential uninitialized memory read.
  - SplashBitmap: Fix wrong width condition for
    splashModeDeviceN8.
  - Fix crashes in malformed files.
- Bump poppler_sover following upstream changes.
* Sun Sep  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Convert linked package to _multibuild
- Cleanup spec file (remove defattr)
- Add boost_headers to BuildRequires, speedup Splash backend
* Fri Aug 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.80.0:
  + core:
  - Annotations: Implement support for setting a different text
    in the appearance stream than the real text.
  - Splash: Optionally use small_vector from boost.
  - Fix memory leaks on broken files.
  - Fix abort on broken files.
  - Small code simplifications.
  - Remove USE_FIXEDPOINT support.
  + qt5:
  - Fix MSVC build.
  - Add subsitute-font information.
  - Fix since marker of some functions.
  - Fix leak when aborting text extraction.
  - Small code simplifications.
  + glib:
  - Make print scaling getter visible.
  - Make Duplex/NumCopies/PrintPageRange preference available in
    API.
  - Implement Movie API.
  + utils: pdftotext: Add -nodiag flag to remove diagonal text on
    output.
  + build system: Mark external lib include dirs as SYSTEM.
- Bump poppler_sover following upstream changes.
- Use cmake_build macro.
* Fri Aug  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.79.0:
  + core:
  - Fix regression on TextSelectionPainter.
  - Fix parsing of DefaultAppearance.
  - Fix memory leak in PostScriptFunction.
  - Fix crashes in fuzzed files.
  + qt5:
  - Implemented support for setIcon by changing appearance.
  - Added option to set the form available to print.
  - QString::null is deprecated, use QString().
  - Replace deprecated qStableSort with std::stable_sort.
  + build system: Turn README into README.md and expand it.
* Fri Jun 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.78.0:
  + core:
  - Fix line annotation arrows for usage in dimensioning.
  - Handle Ink annots without an InkList but with an AP.
  - Fix typos preventing parsing of Movie start and duration.
  - Fix crash on malformed files.
  + glib:
  - Add poppler_document_create_dests_tree().
  - Don't use the deprecated g_type_class_add_private().
  - Document the differences between render() and
    render_for_printing().
  - Fix introspection for poppler_document_new_from_data.
  - Don't create PopplerInputStream with length 0.
  - Document G_IO_ERROR as a possible error condition.
  - Docs: Add index for API new in 0.78.
  + build system:
  - Fixes cross compilation of gir in Void Linux.
  - Add -Wshadow to the default warning flags.
  - Install pkg-config pc files if pkg-config is found.
- Bump poppler_sover following upstream changes.
* Sat May 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.77.0:
  + core:
  - Fix crash on signature handling. Issue #766
  - Fix small memory leak in SignatureHandler::getCertificateInfo
  - Splash: Restrict filling of overlapping boxes. Issue #750
  - Fix crash on malformed files
  + qt5: Fix optional content handling with exclusive layers
  + cpp: Make render_page thread-safe
  + utils:
  - pdfsig: Fix small memory leak
  - pdftotext: Fix typo in manpage
- Changes from version 0.76.1:
  + core:
  - Make the mul tables be calculated at compile time with constexpr.
  - splash: Fix compile with SPLASH_CMYK enabled
  - Some typo fixing in error messages
  + qt5: Fix regression in annotation handling
  + build system: Fix some typos in build system output and comments
- Changes from version 0.76.0:
  + core:
  - Fix regression on case-insensitive search. Issue #743
  - Remove GooList, use std::vector instead
  - Fix radiobutton reporting wrong state. Issue #159
  - Handle UTF16-LE strings
  - Don't error out if there's no DA in FreeText annotation
  - cairo:
    . Compute correct coverage values for box filter.
    . Constrain number of cycles in rescale filter.
  - Read more fields from ViewerPreferences
    . Introduce and use Ref::INVALID
    . Fix crashes in broken files
    . Fix mismatched free/delete
    . Add missing include guards
  + utils: pdftohtml: Properly initialize HtmlOutputDev::page to
    avoid SIGSEGV upon error exit.
- Changes from version 0.75.0:
  + core:
  - Fix rendering of some annotations
  - Fix crashes in broken files
  - Small internal code improvements
  + cpp:
  - Improve documentation
  - tests: Add showing version information to poppler-dump
  + utils:
  - pdfattach: new util
  - pdftohtml: add -dataurls parameter
  - pdftoppm: add -sep and -forcenum parameters
  - pdftohtml: make singleHtml and stout not mutually exclusive
  - pdfsig: fix use after free
- Bump poppler_sover following upstream changes.
* Sun Feb 10 2019 bjorn.lie@gmail.com
- Update to version 0.74.0:
  + core:
  - Remove support for obsolete systems.
  - Include timezone in timeToDateString().
  - Fix/silence some warnings.
  - Fix issues with broken files.
  + build system:
  - Fix linking in FreeBSD.
  - Fix fseeko configure check on Android for API level < 24.
  - Remove unused MacroPushRequiredVars.cmake.
  + qt5:
  - Add API that lazily builds an outline by wrapping the
    internal objects.
  - Demo: Use new API to build Table Of Contents lazily.
  + glib:
  - Improve documentation.
  - Fix cast from 'GTime *' (aka 'int *') to 'time_t *'
    (aka 'long *').
  + utils: pdfsig: add -nssdir option.
  + cpp: Add a way to get all the named destinations in a document.
- Bump poppler_sover following upstream changes.
* Mon Jan 14 2019 bjorn.lie@gmail.com
- Update to version 0.73.0:
  + core:
  - Fix regression reading some encrypted files.
  - Add X509CertificateInfo classes.
  - Add new 'IgnoreDiacritics' option to ::findText().
  - Open files with CLOEXEC flag set.
  - Remove Gulong, Guint, Gushort, Guchar typedefs.
  - Fix handling of some broken files.
  + qt5:
  - Expose X509CertificateInfo.
  - Add the possibility of getting version.
  - Add new 'IgnoreDiacritics' search flag.
  - Make initialization of globalParams threadsafe.
  - ArthurOutputDev: Remove all Splash code usage.
  + cpp:
  - Make initialization of globalParams threadsafe.
  - Fix page::text_list encoding issue.
  - Improve handling of UTF-16 by considering Endianess.
  - Add API to specify a custom data directory.
  + glib:
  - add new 'POPPLER_FIND_IGNORE_DIACRITICS' find flag.
  - Fix named destinations.
  - Make PrintScaling preference available in API.
  + build system:
  - Rename ENABLE_XPDF_HEADERS to
    ENABLE_UNSTABLE_API_ABI_HEADERS.
  - support enabling NSS on mingw.
  - Windows: only set SOVERSION for shared libs.
- Bump poppler_sover following upstream changes.
- Pass ENABLE_UNSTABLE_API_ABI_HEADERS=on to cmake, replacing
  ENABLE_XPDF_HEADERS=on we had before.
* Wed Dec 12 2018 alarrosa@suse.com
- Update to version 0.72.0:
  + core:
  - Fix checkbox lacking AP not being able to change state.
  - Draw line annotation endings (arrow, circle, ...).
  - cairo: Don't use UNIQUE_ID for PS output, to avoid using PS
    memory on cairo >= 1.5.10.
  - Be more stubborn looking for a nssdb.
  - GooString::fromInt: Repair the return value.
  - Minor performance improvements.
  - Avoid cycles in PDF parsing.
  - Stream::makeFilter: Fix memory leak.
  - Fix various issues with malformed files.
  - Rename GooString::getCString to GooString::c_str.
  - Regenerate UnicodeDecompTables.h from python 3.7.1.
  + utils:
  - pdfdetach: Check for valid embedded file before trying to
    save it.
  - pdfdetach: Check for valid file name of embedded file before
    using it to determine save path.
  - Fix typos in utils.
  + glib:
  - Fix missing PopplerAttachment destructor call.
  - Support getting form widget additional actions.
  - docs: Small improvements.
  + qt5: Internally compile with -DQT_NO_SIGNALS_SLOTS_KEYWORDS.
- Bump poppler_sover following upstream changes.
* Fri Nov  2 2018 bjorn.lie@gmail.com
- Update to version 0.71.0:
  + core:
  - Replace the implementation of GooString by std::string but
    keep the exact interface intact.
  - Replace GBool, gTrue, and gFalse by bool, true, false, resp.
  - Splash: Fix crash if document is malformed (too wide).
  + qt5:
  - Fix crash when adding Highlight Annotations.
  - Default to hidden symbols.
  - Fix two leaks in a test.
  + glib:
  - demo: Fix build on Windows.
  - demo: Align property labels to top of cell.
  + cpp: Fix typos in documentation.
  + build system:
  - Enable searching for GTK on Windows
  - Remove unused files
  - Add fuzzer target from oss-fuzz project
- Changes from version 0.70.1:
  + glib: Install missing file.
- Changes from version 0.70.0:
  + core:
  - FreeText annotations: default to font from default appearance
    string.
  - Splash: Speed improvements.
  - Fix security issues found by oss-fuzz.
  - Improve page lable parsing.
  - Use std some std classes instead of self grown ones.
  - Various internal improvements.
  + glib:
  - Fix crash on missing embedded file.
  - Add support for PDF subtype property.
  - Only export symbols in the public API.
  + qt5:
  - Add Page::index() method.
  - Improve method to get the page from a label string.
  + utils: pdftohtml: Improve font handling.
- Bump poppler_sover following upstream changes.
* Mon Oct  1 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version 0.69.0:
  + core:
  - Add annotation font color
  - Splash: Some speed improvements
  - PSOutputDev: add native support for type 7 shadings when
    using level 3
  - Add support for PDF subtype property
  - Link: Fix memory leak regarding next actions
  - Fix handling of Signature Info Location and Reason
  - Fix errors in computation of type3 glyphs transformation
    matrix
  - Reimplement Dict class in a more modern way
  - Fix security issues found by oss-fuzz
  - Fix memory issues in GfxImageColorMap copy ctor
  - Don't abort if the SampleFunction has too many samples.
    Issue glfdo#poppler/poppler#634
  - Document the OutputDev::clip and OutputDev::oeClip methods
  - Fix macOS compilation due to boolean define in jpeglib
  - Split GDir and GDirEntry out of gfile.h.
    Issue glfdo#poppler/poppler#370
  + qt5:
  - Add annotation font color
  + utils:
  - pdfinfo: Show PDF subtype
  - pdftotext: Fix only outputs first page content with
  - bbox-layout option. Issue glfdo#poppler/poppler#88
  - pdftotext: Fix memory leak in printLine
  + build system
  - Require C++14
* Thu Aug 23 2018 bjorn.lie@gmail.com
- Update to version 0.68.0:
  + core:
  - Add Reason and Location to SignatureInfo (fdo#107299).
  - Fix memory misuse on signature handling
  - Fix security issues found by oss-fuzz
  - Don't give a warning when Marked value is false (fdo#107430).
  + qt5: Add Reason and Location to SignatureInfo (fdo#107299).
  + cpp:
  - Add rotation() to text_box (fdo#106562).
  - Fix build with MSVC
  + utils:
  - pdftoppm: Add -jpegopt optimize option support
  - pdftocairo: Add -jpegopt optimize option support
  - pdftohtml:
    . Add option to not round coordinates
    . Fix possible crash (fdo#107316).
  + build system:
  - Use OpenJpeg cmake config file instead of pkgconfig
  - Remove wchar_t- on MSVC
- Changes from version 0.67.0:
  + core:
  - Fix lots of security/leak issues found by oss-fuzz
  - Splash:
    . Optimize some files, making them 20%% faster
    . Correctly manipulate spot colors if SPOT_NCOMPS != 4
  - Fix compilation with some strict compilers.
- Bump poppler_sover following upstream changes.
- Add openjpeg2 BuildRequires: New dependency.
* Thu Jul  5 2018 ecsos@opensuse.org
- Update to version 0.66.0:
  + core:
  - Fix lots of security/leak issues found by oss-fuzz
  - Splash: Optimize some files, making them 20%% faster
  - Splash: Correctly manipulate spot colors if SPOT_NCOMPS != 4
  - Fix compilation with some strict compilers
- Changes from version 0.65.0:
  + core:
  - SplashOutputDev: Add the invisible character check
    beginType3Char. (fdo#106244)
  - XRef: Fix runtime undefined behaviour. (fdo#105970)
  - Fix issues with malformed documents.
    (fdo#104942), (fdo#103238)
  - Remove GooHash after replacing it by std::unordered_map
  - Add conversion methods between GooString and std::string.
  + cpp:
  - Add newline after error message
  - Expose more image modes, add option to select mode in
    renderer. (fdo#105558)
  + build system:
  - Fix compilation with libc++
  - Small improvement to FindLIBOPENJPEG2.cmake
  + qt5:
  - Add widget annot actions to FormFields
  + utils:
  - pdffonts: Minor formatting changes in the man page.
    (fdo#105194)
- Changes from version 0.64.0:
  + core:
  - Workaround form field text not being drawn on broken files.
    (fdo#103245)
  - Add read only setter for form fields
  - Add support for Link Hide action
  - Add support for Next actions in Links
  - Fix parsing of Annot focus out actions
  - Fix PDFDoc::checkHeader() for PDFs smaller than 1 KiB.
    (fdo#105674)
  - Add const to several classes and members
  - gfile: Fix build on some platforms
  - Fix issues with on malformed documents.
    (fdo#105972), (fdo#105969), (fdo#106059), (fdo#106061)
  - Several small code improvements
  + qt5:
  - Allow setting of Form visibility status
  - Allow setting of Form read only status
  - Add support for Link Hide action
  - Add support for Next actions in Links
  - ArthurOutputDev: Implement axialShadedFill
  - ArthurOutputDev: Implement drawImageMask. (fdo#105531)
  - ArthurOutputDev: Implement Type3 font support
  + utils:
  - pdfsig: Add -dump which writes signatures to disk
    (fdo#104881)
  + glib:
  - less deprecated calls
  + build system:
  - bring back the option to disable GObject introspection
  - Add iconv include dir when compiling
  - Make it possible to build poppler without fontconfig.
    Default for Android.
- Bump soversion and data_version to 77 and 0.4.9 respectively.
* Wed Apr  4 2018 idonmez@suse.com
- Update to version 0.63.0:
  + Core:
  - CairoOutputDev: support embedding CCITT image data.
    (fdo#103399)
  - CairoOutputDev: limit image size when printing.
    (fdo#103399)
  - CairoOutputDev: use GOOD instead of BEST as the default
    cairo filter for scaling. (fdo#103136)
  - Error out on save if file has changed since we opened it.
    (fdo#103793)
  - PDFDoc: use %%c instead of \x to output binary. (fdo#103873)
  - Fix index out of bounds undefined behaviour in PSTokenizer.
    (fdo#103583)
  - Fix opening files with OutlineItem loops. (fdo#102914)
  - Fix some bugs in StructTreeRoot parsing of parent tree.
    (fdo#103912)
  - Remove error for wrong child type for tagged pdf.
    (fdo#103587)
  - FoFiTrueType::readPostTable() from xpdf 4.00.
    (fdo#102880)
  - GfxFontDict: merge reference generation from xpdf 4.00.
    (fdo#104565)
  - Reset lastAbortCheck on updateLevel reset
  - PDFDoc::setup: Fail early if base stream length is 0.
    (fdo#103552)
  - Check curStr is actually a Stream before doing Stream
    operations. (fdo#104518)
  - Fix new Object API porting bug. (fdo#104517)
  - Check return code of getChar(), abort reading on error.
    (fdo#104502)
  - TextPage: Add horizontal scaling to font matrix.
    (fdo#105259)
  - Fix EmbedStream replay. (fdo#103446)
  - Fix memory leak on error condition
  - Fix assert on malformed documents. (fdo#104354)
  - Fix abort in Gfx::opBeginMarkedContent if args[1] is not
    a name. (fdo#104468)
  - GfxGouraudTriangleShading::parse: Don't abort on malformed
    documents. (fdo#104567)
  - GfxFunctionShading::parse: Fix abort in malformed document.
    (fdo#104581)
  - Remove the extern C from glib.h. (fdo#103621)
  - Don't let ArthurOutputDev be friend of SplashPath anymore
  - Fix undefined sanitizer warning about qsort
  - Form.h: include time.h for time_t
  - Various code improvements
  + Qt5:
  - Add cancellation support to renderToImage and textList
  - Do not assume all Screen annotation actions are Renditions.
    (kde#388175)
  - qt5: Implement operator= for PageTransition
  - ArthurOutputDev: 'clip' should intersect new and old clipping
    path
  - ArthurOutputDev: Implement updateBlendMode
  - ArthurOutputDev: Replace the QPainter by a stack of QPainters
  - ArthurOutputDev: Rudimentary support for transparency groups
  - Remove stale libcms1 code. (fdo#104358)
  - demo: don't crash if page is malformed
  - Fix warnings due to the use of deprecated overloads of
    Poppler::Page::Search in tests.
  + Utils:
  - pdfimages: Fix for files with flate encoded inline images.
    (fdo#103446)
  - pdftocairo: Remove stale libcms1 code. (fdo#104358)
  - pdfimages: Fix build without libtiff and libpng
  - pdfseparate: Fix buffer size warning due to missing space
    for null terminator
  + Build System:
  - Enable building all libs as static libs
  - Enable no-missing-field-initializers
  - Remove unused FindLIBOPENJPEG.cmake
  - Add "--owner root:0 --group root:0" options to tar command
    in dist target. (fdo#104398)
  - Add python3 support to gtkdoc.py
  - gtkdoc.py: Make it work with newer gtk-doc. (fdo#105075)
  + Cpp:
  - Add page::text_list
* Sat Dec 16 2017 hpj@urpla.net
- make introspection scanner (g-ir-scanner) work with older build envs
* Sun Dec 10 2017 luc14n0@linuxmail.org
- Update to version 0.62.0:
  + Core:
  - Stop supporting lcms1 and openjpeg1.
  - Open files that state 8 bits as third field of W
    (fdo#103469).
  - GfxLabColorSpace::parse: fix crash in broken documents
    (fdo#103582).
  - Fixes: leak if parseDA fails. And UTF test fail.
  - Include glibc.h where needed.
  - Document the meaning of the 'type' integer of a shading.
  - INSTALL: add debug options.
  + Qt5: add API to let the rendering process callback to get a
    partial rendering (fdo#103372).
  + Qt4: remove the Qt4 frontend.
  + Utils:
  - Support unicode on windows console.
  - pdfsig: install man page.
  - sort encoding list.
  + Glib: demo: fix warning.
- Remove Qt4 poppler package following upstream change.
- Drop conditional use of openjpeg-devel BuildRequires and mainly
  use pkgconfig(libopenjp2) instead, following upstream change.
- Drop Provides/Obsoletes meant for pristine openSUSE 10.3,
  11.1/(SLE 11) and 11.4 releases.
* Wed Nov 22 2017 luc14n0@linuxmail.org
- Update to version 0.61.1:
  + Core: CairoOutputDev: don't overflow y * stride when accessing
    image data.
  + Build system:
  - Fix incorrect paths in .pc files (fdo#103578).
  - add the custom buildtests target only once (fdo#103003).
- Changes from version 0.61.0:
  + Core:
  - Fix crashes in broken files.
  - Cleanup unused functions from GlobalParams.
  - Tweak LZWStream::processNextCode error handling (fdo#103174).
  - Warning fixes.
  - Remove t1lib code.
  + Qt5:
  - Clean up the remaining Splash code in Arthur backend
    (fdo#103117).
  - ArthurOutputDev: Properly implement saveState/restoreState
    (fdo#103118).
  - Fix leak in ArthurOutputDev::updateFont (fdo#103508).
  + Build system:
  - Use GNUInstallDirs (fdo#103211).
  - Fix installing a .cc file as header.
  - Use -pthread flag instead of -lpthread.
- Changes from version 0.60.1:
  + Qt5: ArthurOutputDev: Add missing 'return' in error paths.
  + Build system: FindLIBOPENJPEG.cmake:
    Add CheckCXXSourceCompiles.
- Changes from version 0.60.0:
  + Core:
  - Enable libcurl support by default.
  - PSOutputDev: Fix wrong text generation (fdo#102760).
  - Added methods to get and set the font size of text fields
    (fdo#101692).
  - CairoOutputDev: Do not extend the pattern in
    drawImageMaskRegular.
  - CairoOutputDev: do not use the custom downscaling for
    rendering images when using cairo >= 1.14.
  - Fix: Build with old clang. Various crashes in broken files.
    And some warnings.
  - Add some constness to the basic classes.
  - Remove unused functions from GlobalParams.
  + Qt5:
  - Added methods to get and set the font size of text fields
    (fdo#101692).
  - Add whether renderToImage shows annotations.
  - ArthurOutputDev:
    . Replace Splash font rendering by Qt font rendering.
    . Implement the drawSoftMaskedImage method.
    . Fix several small bugs related to dash pattern handling.
  + Build system:
  - cmake is now the default build system.
  - autotools based build system has been removed.
  + Utils: pdfinfo: don't truncate dest name.
- Drop CVE-2017-14517.patch and CVE-2017-14518.patch: fixed
  upstream (fdo#102687 and fdo#102688, respectively).
- Add cmake BuildRequires; replace configure, make and make_install
  macros, with cmake, make_jobs and cmake_install: following
  upstream port.
- Add glib2-devel BuildRequires as it's a dependency required by
  CMakeLists.
- Drop command for removal of *.la files: with the build system
  port to cmake, *.la are no longer generated.
* Mon Oct  9 2017 jengelh@inai.de
- Update package summaries and RPM categorizations.
- Drop some idempotent %%if..%%endif markers whose presence has
  no effect on the files being output.
* Mon Oct  9 2017 psimons@suse.com
- Apply CVE-2017-14517.patch from upstream to fix a NULL pointer
  dereference in the XRef::parseEntry() function that may have lead
  to potential denial-of-service attack when handling malicious PDF
  files. [CVE-2017-14517, bsc#1059066]
* Mon Sep 18 2017 psimons@suse.com
- Apply CVE-2017-14518.patch to remedy a floating point exception
  in Splash.cc that could have been exploited using a specially
  crafted PDF document. [CVE-2017-14518, bsc#1059101]
* Thu Sep  7 2017 zaitor@opensuse.org
- Update to version 0.59.0:
  + core: Fix infinite recursion in NameTree parsing in broken
    files.
  + utils:
  - pdfunite: Fix API porting error that caused abort in some
    cases.
  - pdfinfo:
    . Fix crashes and memory leaks when using -dests.
    . Use GooString.append instead of sprintf/strcat.
  - pdfimages: Fix warning when compiling with cygwin.
  + build system:
  - Fix cygwin 32-bit compile.
  - Cmake tweaks.
- Bump soversion following upstream changes.
* Sun Sep  3 2017 zaitor@opensuse.org
- Update to version 0.58.0:
  + core:
  - CairoOutputDev: cairo 1.14 now has high quality downscaling.
  - Signature related improvements (fdo#99271).
  - Tweak which cmap we use (fdo#101855).
  - Memory leak fixes.
  - Substantial rework of the internals.
  - win32: call ANSI functions directly (fdo#100312).
  - Add some documentation.
  + qt5:
  - Expose signature information.
  - ArthurOutputDev: initialize the image with the paper color
    (fdo#102129).
  - Fix copy'n'paste bugs: Qt4 -> Qt5.
  - ArthurOutputDev: Properly set the QPainter transformation.
  - ArthurOutputDev: Use Qt::SvgMiterJoin instead of
    Qt::MiterJoin (fdo#102356).
  + utils:
  - pdfinfo: add -dests option to print named destinations
    (fdo#97262).
  - pdftocairo: add -jpegopt for setting jpeg compression
    parameters (fdo#45727).
  - pdftoppm: add -jpegopt for setting jpeg compression
    parameters (fdo#45727).
  - pdfimages: support listing/extracting inline images
    (fdo#25625).
  + build system:
  - cmake: Various Windows fixes.
  - cmake: Use -std=c++11 instead of -std=gnu++11.
  + cpp: Fix page.text() not taking page orientation into account
    (fdo#94517).
- Bump soversion following upstream changes.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 0.57.0:
  + core:
  - Fix parsing of Type 1 fonts with newlines in encoding
    sequences (fdo#101728).
  - Fix crash in broken documents.
  + utils:
  - pdfunite: Fix crash with broken documents (fdo#101208).
  - pdftohtml: skip control characters (fdo#101770).
  - pdfseparate: minor improvement to the documentation
    (fdo#101800).
  + build system:
  - cmake: Set RUNPATH for poppler shared libs (fdo#101945).
  - configure: fix --disable-FEATURE actually enabling the
    feature.
- Bump soversion following upstream changes.
* Thu Jun 22 2017 zaitor@opensuse.org
- Update to version 0.56.0:
  + core:
  - FormFieldButton::setState() shouldn't check the field is
    readOnly.
  - Fix crashes on multiple broken files.
  + utils: pdfunite: Fix crash with broken documents (fdo#101153,
    fdo#101149).
- Drop poppler-pdfunite-fix-crash-with-broken-documents.patch:
  Fixed upstream.
* Sun Jun 11 2017 zaitor@opensuse.org
- Add poppler-pdfunite-fix-crash-with-broken-documents.patch:
  pdfunite: Fix crash with broken documents. Sometimes we can't
  parse pages so check before accessing them (bsc#1043088,
  bsc#1041783, CVE-2017-7515, CVE-2017-7511, fdo#101153,
  fdo#101149).
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 0.55.0:
  + core:
  - Fix abort in files with broken Decode arrays (kde#379835).
  - Fix memory leak (and probably logic bug) parsing broken XRef
    entries (fdo#100775).
  - Fix memory leak when reconstructing broken files
    (fdo#100776).
  - Minor optimization.
  - Fix regression in GfxIndexedColorSpace::mapColorToBase
    (fdo#100931).
  - Fix memory leak in error condition.
  + cpp: Return nullptr if the page at index can't be fetched
    (fdo#100981).
  + build system:
  - Fail by default if libjpeg is not available.
  - Fail by default if libopenjpeg2/1 is not available.
* Sun May 21 2017 zaitor@opensuse.org
- Update to version 0.54.0:
  + core: Make XRef reconstruction a bit better (fdo#100509).
  + glib:
  - Expose movie play mode (fdo#99625).
  - demo: Show play mode in movie properties view.
  + qt5: Compile with -DQT_NO_CAST_FROM_BYTEARRAY (fdo#100311).
  + utils: pdfimages: don't fail listing if inline image data
    contains 'EI' (fdo#100737).
* Thu Mar 23 2017 zaitor@opensuse.org
- Update to version 0.53.0:
  + core:
  - Form support improvements.
  - SplashOutputDev: Fix memory leak when rendering images with
    colormap and matte color.
  - Minor fix in GlobalParams documentation.
  + qt5:
  - Expose form calculate order.
  - Expose Form additional actions.
  + utils:
  - pdfimages: support 16bpc png and tiff images (fdo#99988).
  - pdftohtml: fix small memory leak when constructing some
    filenames.
  - pdfinfo: fix leak when printing JS.
  + build system: Compile in C++11 mode.
- Bump soversion following upstream changes.
- Stop exporting  -std=gnu++11 for older versions of gcc, upstream
  now ensures this happens.
* Fri Feb 17 2017 zaitor@opensuse.org
- Update to version 0.52.0:
  + core:
  - Fix assert on reading some OCGs (fdo#99768).
  - Properly initialize some RichMedia variables in corner cases
    (fdo#99767).
  + qt4:
  - optcontent structure was leaking the headers items
    (fdo#99449).
  - Cleanup objects in tests to fix memory leaks (fdo#99449).
  + qt5:
  - optcontent structure was leaking the headers items
    (fdo#99449).
  - Cleanup objects in tests to fix memory leaks (fdo#99449).
  + utils: pdftocairo.1: Fix typo.
* Tue Jan 17 2017 zaitor@opensuse.org
- Update to version 0.51.0:
  + core:
  - Check for error from NSS in SignatureHandler construct
    (fdo#99363).
  - Add Form[Field|Widget]::setPartialName
  - Fix memory leak in PDFDoc::markAnnotations.
  + qt5:
  - Implement digital signature support (fdo#94378).
  - Add Poppler::FormField::setName
  - Fix segfault/assert if LinkDestination is constructed with
    invalid input string (fdo#99357).
  + utils: pdfunite: add fields to AcroForm dict (fdo#99141).
* Fri Dec 16 2016 zaitor@opensuse.org
- Update to version 0.50.0:
  + core:
  - PSOutputDev: Fix PS conversion for some files (fdo#63963).
  - Fix Outline parsing on broken documents (fdo#98732).
  - Fix PDFDoc::saveIncrementalUpdate()'s detection of document
    being modified (fdo#96561).
  - SplashOutputDev: Read softmask into memstrean in case of
    matte (fdo#97803).
  - Bail out if Hints nBitsNumObjects or nBitsDiffGroupLength are
    greater than 32 (fdo#94941).
  - CairoOutputDev: initialize CairoOutputDev::antialias
    (fdo#98983).
  - Fix crash when loading some thumbnails (fdo#97870).
  + utils:
  - pdftoppm: Fix -tiff -gray/-mono incorrect output.
  - pdftops: add -passlevel1customcolor (fdo#97193).
  + build system: Default to libopenjpeg2 instead of libopenjpeg1.
  + qt: Support OCG state change links.
  + glib: Use g_slice_new0 for PopplerActionLayer (fdo#98786).
- Bump soversion following upstream changes.
* Mon Nov 21 2016 zaitor@opensuse.org
- Update to version 0.49.0:
  + core:
  - Merge type3 glyph handling from xpdf 3.04 (fdo#96667).
  - Continue rendering in case of 'Singular matrix in shading
    pattern fill (bgo#98623).
  - Fix memory leak in parametrized gouraudTriangleShadedFill.
  - Fix crash on broken files.
  - PDFDoc::setDocInfoStringEntry(): treat value consisting of
    just the unicode marker as an empty string.
  - Fix UBSAN warning.
  - Misc compile fixes.
  + utils: pdfseparate: remove extra '%%' in error message.
  + build system: configure: Fix typo in disable nss help string.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 0.48.0:
  + core:
  - Fix crashes and memory leaks in invalid files.
  - Small memory usage improvements.
  - TextOutputDev: Remove null characters from PDF text
    (fdo#97144).
  - TextOutputDev: Break words on all whitespace characters
    (fdo#97399).
  - Fix UTF16 decoding of document outline title (fdo#97156).
  - Add functions for named destination name in name-tree/dict.
  + glib: Increase glib requirement to 2.41.
- Bump soversion following upstream changes.
* Fri Aug 19 2016 wbauer@tmo.at
- Update to version 0.47.0 (boo#994702):
  + core:
  - Fix abort on documents where the docinfo obj is not a dict
    (fdo#97134).
  - Check for XRefEntry existing before using it (fdo#97005).
  - Fix memory leak on PDFDoc::setDocInfoStringEntry() with empty
    string.
  - Don't presume that DocInfo is a dictionary in
    XRef::createDocInfoIfNoneExists().
  + build system: configure: Work with non gnu greps.
* Fri Jul 29 2016 jengelh@inai.de
- The "poppler_soname" macro (and others) really just contained the
  version (not the entire name), so rename to "popple_sover".
* Tue Jul 26 2016 zaitor@opensuse.org
- Update to version 0.46.0:
  + core:
  - cairo:
    . Fix bug in setAntialias().
    . Fix tiling patterns with BBox with non-zero x,y.
    . Try finding glyphs in substitute fonts by unicode value
    (fdo#96994).
  - Added XRef modification flag.
  - Added DocInfo setters & getters.
  - Be less strict when parsing FitH Link destinations
    (fdo#96661).
  + utils:
  - pdftocairo:
    . Revert the use of groups for blending into white page.
    . Use fprintf for printing errors.
  - pdfinfo: Don't print pdf info when printing metadata,
    javascript, or structure (fdo#96801).
  + glib:
  - Added document property setters & simplified getters.
  - Make document metatag gobject properties writeable.
  + cpp:
  - Pass len to GooString constructor in
    detail::ustring_to_unicode_GooString() (fdo#96426).
  - Added functions to save a document.
  - Added document property setters & getters.
  + qt4: Added document property setters & simplified getters.
  + qt5: Added document property setters & simplified getters.
  + build system:
  - configure:
    . Don't use -fPIC on cygwin.
    . Work with non gnu greps.
- Bump soname following upstream changes.
* Sun Jun 19 2016 hrvoje.senjan@gmail.com
- Qt 5.7 needs gnu++11 standard, export the appropriate flag in
  spec when compiler doesn't enforce it by default.
* Sat Jun 18 2016 zaitor@opensuse.org
- Update to version 0.45.0:
  + core:
  - SplashOutputDev: Fix iccTransform + splashModeXBGR8.
  - Fix memory leaks.
  - Fix crash in broken files (fdo#95567, fdo#96027).
  - Emulate some non portable glibc functions when not
    available.
  + utils:
  - pdftohtml: Fix crash in broken files (fdo#95563).
  - pdfinfo:
    . Convert dates to local time zone.
    . Add -isodates for printing dates in ISO-8601 format.
    . Fix memory leaks.
  + glib: Return date in UTC instead of local time (fdo#94173).
  + cpp: Switched from detail::convert_date() to core's
    dateStringToTime().
- Bump soname following upstream changes.
- Drop poppler-Fix-mem-leak-SplashgouraudTriangleShadedFill.patch:
  Fix upstream.
* Mon May 23 2016 zaitor@opensuse.org
- Update to version 0.44.0:
  + core:
  - Fix Compile in 32bit linux (fdo#95492).
  - Splash: type 3 chars. restore the current position also in
    output device (fdo#95344).
  - Splash: Improve rendering of some dotted lines (fdo#84693).
  - Refactor GooString::Set() (fdo#94201).
  - Fix typo in GfxPatchMeshShading::parse.
  - Fix memory leak in PSOutputDev::filterPSLabel.
  - Fix memory leak in
    SignatureHandler::getDefaultFirefoxCertDB_Linux.
  - Fix potential crash in SplashOutputDev::doUpdateFont.
  - Fix potential crash in TextPage::coalesce.
  - Remove call that does nothing.
  + utils: pdftocairo: add -antialias option (fdo#94977).
- Bump soname following upstream changes.
- Add poppler-Fix-mem-leak-SplashgouraudTriangleShadedFill.patch:
  Fix memory leak in Splash::gouraudTriangleShadedFill, patch from
  upstream git.
* Mon May  2 2016 zaitor@opensuse.org
- Update to version 0.43.0:
  + core:
  - Implement sanity check for linearization usage (fdo#92482).
  - Add SymbolMT as an alias for the Symbol font (fdo#93168).
  - Fix some blank files (fdo#94756).
  - cairo:
    . Fix fillToStrokePathClip crash and rendering (fdo#62905).
    . Check if PDF knows the width of 'm' in case of substituted
    font (fdo#94054).
    . Save mask state and don't extend image mask (fdo#94234).
  - SplashOuputDev: Compile with C++11 compilers that don't
    define isinfinite (fdo#94761).
  - Typo fixes.
  + utils: pdftocairo: Calculate rotation before scaling
    (fdo#94655).
  + qt4: Fix crash on certain PDF form item activation actions
    (fdo#94873).
  + qt5: Fix crash on certain PDF form item activation actions
    (fdo#94873).
- Drop poppler-Fix-rendering-of-broken-pdfs.patch, fixed upstream.
- Bump soname following upstream changes.
* Tue Apr  5 2016 zaitor@opensuse.org
- Add poppler-Fix-rendering-of-broken-pdfs.patch: Fix pdf rendering
  commit (boo#973888 bgo#764641 fdo#94830).
* Fri Mar 18 2016 zaitor@opensuse.org
- Update to version 0.42.0:
  + core:
  - Add the support for version 5 + revision 6 documents
    (fdo#85368).
  - Add initial support for Signature handling.
  - Initialize gamut mapping multipliers in ::copy() functions
    (fdo#90697).
  - Implement jpx streams support with depth < 8.
  - Handle SMaskInData = 0 for JPX encoded images (fdo#93468).
  - Fix rendering of some broken PDF files (fdo#92508).
  - PSOutputDev:
    . Support for LZW encoding.
    . Add support for Flate compression in Level 3 output.
  - SplashOuputDev:
    . Implement function shading (fdo#94441).
    . Improve rendering of some non embedded fonts (fdo#94054).
    . Fall back to Gfx implementation of tiling pattern if
    repetition rate is small (fdo#90596).
    . Implementation of Matte entries in softmasks of
    softmasked images (fdo#22473).
    . Assure line width > 0 in case of text stroke (fdo#94038).
  - TextOuputDev: Cache result of inner loop in visitDepthFirst
    (fdo#77087).
  - Avoid attempting a tiling pattern fill with a singular
    transform matrix.
  + utils:
  - pdfinfo: Add option to show document structure
  - pdfsig: New command that gives information about signature
  + qt4: Fix bug in links to remote documents getting the page
    number wrong sometimes.
  + qt5: Fix bug in links to remote documents getting the page
    number wrong sometimes.
- Add pkgconfig(nss) BuildRequires: Build nss support.
- Bump soname following upstream changes.
* Thu Feb 18 2016 zaitor@opensuse.org
- Update to version 0.41.0:
  + core:
  - CairoOutputDev: add missing font types (fontCIDType0COT and
    fontTrueTypeOT) (fdo#93559).
  - SplashOutputDev: Adjust limit check and check in addition
    bitmap pointer (fdo#94053).
  + utils:
  - pdfseparate: Refine resource detection.
  - pdfinfo: fix man page.
* Fri Jan 15 2016 zaitor@opensuse.org
- Update to version 0.40.0:
  + core:
  - CairoOutputDev: Use shape mask with soft mask (fdo#91931).
  - TextOutputDev:
    . Handle right-to-left text in search
    . Fix finding Arabic Presentation Forms ligatures.
  - Fix crash in invalid file (fdo#93476).
  - Regression test improvements.
  + utils:
  - pdftocairo:
    . Fix writing to stdout out with image output.
    . Document that -singlefile appends file type (fdo#86254).
    . Ensure surface flushed before accessing image data.
    . Check for invalid use of options (fdo#92195).
  - pdfunite: Fix typo in manual.
  + build system: Improve cmake build system.
* Fri Dec 18 2015 zaitor@opensuse.org
- Update to version 0.39.0:
  + core:
  - Ignore the alternateSpace and tintTransform (fdo#92381).
  - CairoOutputDev:
    . Scale radial pattern (fdo#22098).
    . Implement function shading using mesh gradients
    (fdo#88394).
  - Regression test improvements.
  - Fix typos in error messages.
  + build system: Visual Studio 2015 now supports snprintf
    (fdo#93116).
  + utils:
  - pdftops: fix %%%%PageBoundingBox (fdo#87161).
  - pdftocairo: Fix double free when both user and owner
    passwords are given.
  + glib:
  - Add duration_real to PopplerPageTransition (fdo#92040).
  - Remove enum PopplerOrientation from API (fdo#93229).
  - Documentation improvements.
  - glib-demo improvements.
- Bump soname following upstream changes.
* Tue Nov 17 2015 zaitor@opensuse.org
- Update to version 0.38.0:
  + core:
  - Splash: Multiply opacity in case of pattern colorspace
    (fdo#92592).
  - Small form improvements on non ascii character rendering.
  - Clarify README.
  + build system: Clarify internal DCT and JPX are only provided as
    deprecated fallbacks.
  + utils: pdftocairo: fix fit to page transformation.
- Bump soname following upstream changes.
* Sat Oct 10 2015 zaitor@opensuse.org
- Update to version 0.37.0:
  + core:
  - CairoOutputDev: Use mask for even-odd fill (fdo#84527).
  - SplashOuputDev: Protect calls to set/getAA with the proper
    [#]if guards (fdo#92006).
  - SplashOuputDev: Try to use an external font if the internal
    one is invalid.
  - PageTransition D is a number not an int (fdo#92040).
  - Catalog::getNumPages(): validate page count.
  - Catalog::cachePageTree(): recover from out of memory
    condition.
  - Fix crashes in malformed documents.
  + build system: configure: fix openjpeg detection.
- Use pkgconfig(libopenjp2) BuildRequires for openSUSE newer than
  13.1, stay with openjpeg-devel for older releases.
- Bump soname following upstream changes.
* Fri Sep 11 2015 zaitor@opensuse.org
- Update to version 0.36.0:
  + core:
  - Patch to support RichMedia annotations.
  - Splash: Fix wrong memory access (fdo#91686).
  - Cairo: fix size of transparency group surface (fdo#66229).
  - Fix bounds check in Linearization::getPageFirst (fdo#91200).
  - File Saving improvements.
  - Add premultiplied alpha channel to SplashBitmap.
  - Fix for xref table creation (fdo#90790).
  - Fix JBIG2Decode infinite loop and stack overflow (fdo#91186).
  - Minor optimization in text extraction.
  + qt4:
  - Basic support for RichMedia annotations.
  - Change default image format.
  - Minor optimizations.
  + qt5:
  - Basic support for RichMedia annotations.
  - Change default image format.
  - Minor optimizationsHEADmaster.
  + cpp: Fix utf8/utf16 conversion (fdo#91644).
  + build system:
  - Do not hardcode -fPIC in Makefile.am.
  - cmake: Allow configuring SHARE_INSTALL_DIR (fdo#90293).
  + utils:
  - pdfunite: Insert embedded files in result pdf (fdo#90066).
  - pdftotext: Add -bbox-layout option (fdo#89941).
- Bump soname following upstream changes.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.35.0:
  + core:
  - Fix assert in broken file (fdo#91344).
  - Adjust memory layout computation of GooString.
  - Make SplashBitmap XBGR transfer alpha channel.
  - Splash: Fix wrong writes on non rgb outputs (fdo#90570).
  - Splash: remove ifndef in Windows code.
  - GlobalParamsWin bugfixes (fdo#91053).
  + qt4:
  - Switch default image format.
  - Add IgnorePaperColor render flag.
  + qt5:
  - Improve efficiency of Poppler::Page::renderToImage.
  - Switch default image format.
  - Add IgnorePaperColor render flag.
  + build system:
  - Allow configuring SPLASH_CMYK support.
    + Add configure --enable-build-type (fdo#90796).
  + glib:
  - Explicitly link against pthread.
  - Deprecation fixes.
  + utils: pdftocairo: Fix cast to pointer from integer of
    different size on win64.
- Bump soname following upstream changes.
* Thu Jul  9 2015 zaitor@opensuse.org
- Update to version 0.34.0:
  + core:
  - Splash:
    . Fix crash in PDF with nested softmasks (fdo#91240).
    . Speed up of rendering icc based images (fdo#90171).
  - PSOutputDev: Embed Type1 fonts to PostScript files correctly
    (fdo#19747).
  - Fix pedantic memory leak.
  + glib: Update new symbols section.
  + Build system: cmake: Make sure ENABLE_LIBOPENJPEG is either 0
    or 1.
- Bump poppler soname following upstream changes.
* Sun May 17 2015 zaitor@opensuse.org
- Update to version 0.33.0:
  + core:
  - Fix regression in pdftops parameter passing (fdo#89827).
  - Combine base characters and diacritical marks (fdo#87215).
  - Use width from W array for WMode positioning (fdo#89621).
  - Fixed adding annotation of Subtype Popup to pdf page
    (fdo#89136).
  - CairoOutputDev: Fix memory leak in CairoFreeTypeFont::create.
  - SplashOutputDev: memset on error to have reproducible
    outputs.
  + qt4: Fix PDF Text String -> QString conversion (kde#344849).
  + qt5: Fix PDF Text String -> QString conversion (kde#344849).
  + glib:
  - Add poppler_annot_markup_set_popup_rectangle()
  - Fix segfault when creating PopplerAction (fdo#90093).
  + utils: pdftohtml: Set exit status adecuately (fdo#83609).
  + build system: configure: Fix invalid shell comparaison in
    libtiff test.
- Bump poppler soname following upstream changes.
* Sat Mar 21 2015 zaitor@opensuse.org
- Update to version 0.32.0:
  + core:
  - Annotations: Fix rendering of empty BG/BC arrays.
  - Splash:
    . Fix wrong colour shown when GouraudTriangleShFill uses a
    DeviceN colorspace (fdo#89182).
    . Fix use of uninitialized variable in Splash::pipeRun.
  - Remove unnecesary check for font validity (fdo#88939).
  - Small optimization in GooString::appendfv() (fdo#89096).
  - Fix crashes in malformed files.
  + utils:
  - pdftops: Make colorpsace optimization an option instead of
    default.
  - pdfseparate: use always an unique instance for PDFDoc for
    savePageAs.
  + build system:
  - cmake: If extra-cmake-modules is around include the
    Sanitizers module.
- Bump poppler soname following upstream changes.
* Sat Feb  7 2015 zaitor@opensuse.org
- Update to version 0.31.0:
  + core:
  - CairoOutputDev: support embedding JBIG2 image data.
  - Accept malformed documents whose root is a Page instead of a
    Pages (fdo#88172).
  - Fix crash on broken documents.
  - JPEG2000Stream: Inline doGetChar and doLookChar.
  - GlobalParams cleaning.
  + utils: pdftops: Add rasterization option (fdo#85934).
  + qt4: Expose whole-words search option.
  + qt5: Expose whole-words search option.
- Bump poppler soname following upstream changes.
* Thu Feb  5 2015 coolo@suse.com
- reset baselibs.conf for rebuilds
* Tue Jan  6 2015 zaitor@opensuse.org
- Update to version 0.30.0:
  + core:
  - Openjpeg2 support (openjpeg 1 is preferred) (fdo#58906).
  - Fix potential memory corruption on TextSelectionDumper
    (fdo#84555).
  - Check for invalid matrix in annotation (fdo#84990).
  - Open some not conforming files (fdo#85919).
  - PSOutputDev: Accept a list of pages indeces instead of first,
    last (fdo#84833).
  - Fix memory leak on error condition.
  + cpp: New API to set debug output function.
  + build system: configure: Improve support with older clang
    versions (fdo#76963).
  + utils: pdfunite: Support output intents, optional content and
    acroform.
- Bump poppler soname following upstream changes.
* Fri Dec 26 2014 zaitor@opensuse.org
- Update to version 0.29.0:
  + core:
  - Use correct LAB byte array for lcms input (fdo#86388).
  - Write correct size in trailer dict (fdo#86063).
  - Use Default colorspaces if present instead of Device
    colorspaces.
  - Solve blend mode problem in CYMK and DeviceN for separable
    blend modes.
  - Compilation/warning fixes on SunOS.
  - Regression test improvements.
  + glib: demo: Compilation fixlets.
  + build system: cofigure: print "no" instead of "auto" if lcms
    not found.
- Bump poppler soname following upstream changes.
* Sat Dec 13 2014 crrodriguez@opensuse.org
- BuildRequire libcurl so the library can operate on remote
  HTTP documents.
* Tue Nov  4 2014 zaitor@opensuse.org
- Update to version 0.28.1:
  + Fix small typo that made pkg-config fail on some systems.
- Changes from version 0.28.0:
  + core:
  - Fix rendering of file with a wrong embedded font (fdo#84270).
  - Use alt colorspace to get CMYK values for an ICC based CMYK
    colorspace (fdo#79019).
  - Map Standard/Expert encoding ligatures to AGLFN names
    (fdo#80093).
  - Make Attribute::getName() work when UTF-16BE is used
    (fdo#84722).
  - Fix memory leak in Dict::remove (fdo#84607).
  - Fix crashes in broken files.
  + SplashOutputDev: Improve Overprintmode and shadings
    (fdo#80998).
  + CairoOutputDev:
  - Fix crash when no group color space (fdo#85137).
  - Don't render text when text matrix is not invertable
    (fdo#78042).
  - Only embed mime data for gray/rgb/cmyk colorspaces
    (fdo#80719).
  - Only embed mime data if image decode map is identity.
  + cairo:
  - Use matrix to determine pattern size (fdo#33364).
  - Fix compile warnings.
  - Regression test improvements.
  + glib:
  - Fix use of uninitialized members in PopplerInputStream
    (fdo#82630).
  - Documentation improvements.
  - Do not dist gir_DATA.
  - Remove use of GTK deprecated functions (fdo#82384,
    fdo#82385).
  - Build introspection linking to the uninstalled libraries
    (fdo#84526).
  + qt4: Add a new Page::annotations() that let's you specify
    subtypes.
  + qt5: Add a new Page::annotations() that let's you specify
    subtypes.
  + utils:
  - pdfseparate: additonal handling for annotations (fdo#77549).
  - pdfdetach: fix crash when getPage() returns null (fdo#85145).
  - pdftocairo: Add support for printing to a Windows printer
    (fdo#79936).
  + build system:
  - Move automake version check from autogen.sh to configure.ac
    (fdo#79797).
  - Makefile.am cleanups (fdo#79411).
  - Use poppler-data pkg-config.
  - Make autogen.sh work with variables with spaces.
  - Don't use -fPIC on mingw.
  - Fix build with --disable-utils (fdo#84448).
- Bump poppler soname following upstream.
* Thu Oct 16 2014 hrvoje.senjan@gmail.com
- Add missing baselibs.conf, but as empty file. Since this package
  is a bit different in number of built libraries, number of
  linked packages, and the fact that there is often soversion
  change - generate current library names during buildtime
* Sat Sep 27 2014 zaitor@opensuse.org
- Update to version 0.26.5:
  + core: Fix rendering of broken file with a wrong embedded font
    (fdo#84270).
  + glib: Fix use of uninitialized members in PopplerInputStream
    (fdo#82630).
* Tue Sep  9 2014 zaitor@opensuse.org
- Update to version 0.26.4:
  + core:
  - CairoOutputDev: Make sure we always push a transparency group
    in setSoftMaskFromImageMask() (fdo#81624).
  - Fix a crash when adding Annotation without contents.
  - Improve non-latin characters in inline notes (fdo#65956).
  - Don't check for inlineImg twice (fdo#82059).
  - printf() -> error().
  + glib:
  - Return NULL in poppler_annot_get_contents also for empty
    strings.
  - Fix a memory leak when getting text layout and attributes.
* Mon Aug  4 2014 zaitor@opensuse.org
- Update to version 0.26.3:
  + qt5:
  - autoconf: Improve moc-qt5 detection.
  - Fix compilation with MinGW.
  + glib:
  - Fix typo in api docs.
  - Use C90-style comments in public headers.
  + core: Error out instead of exiting if allInter grows too much
    (fdo#78714).
  + qt4: Update required version to Qt 4.7.0.
  + build system: Include stdio.h from poppler-config.h.
  + misc: Update .gitignore files.
* Sat Jul 12 2014 zaitor@opensuse.org
- Update to version 0.26.2:
  + core: Make sure we have an xref before using (kde#335413).
  + build system: autoconf: Fix typo in configure.ac.
  + utils: pdftohtml: exit with 0 with -v and -h.
- Changes from version 0.26.1:
  + core:
  - Use field value V for radio buttons (fdo#75979).
  - Fix extraction of text in some files (fdo#78145).
  - Only add annotations of the current page when splitting
    (fdo#77549).
  + build system: autoconf: Fix libopenjpeg 1.5 detection on some
    systems (fdo#78389).
  + glib: Fix multiple definition of PopplerTextSpan.
* Wed Apr 30 2014 hrvoje.senjan@gmail.com
- Enable build of Qt5 subpackage
- Disable poppler-glib and poppler-cpp building with Qt4/5 subpackages
* Tue Apr 29 2014 zaitor@opensuse.org
- Update to version 0.26.0:
  + qt4: Fix mismatched boolean logic in
    TextAnnotation::setInplaceIntent.
  + qt5: Fix mismatched boolean logic in
    TextAnnotation::setInplaceIntent.
  + core: Very small code cleanup.
  + cpp: Very small code cleanup.
- Changes from version 0.25.3:
  + core:
  - Fix crashes on broken files.
  - Avoid MinGW/Cygwin warnings due to redefinition of NOMINMAX.
  - Fix some small memory leaks.
  + qt5:
  - Fix some kinds of OCG models.
  - Cleanup some deprecated methods.
  + glib:
  - Fix the first coord of the quadrilateral in
    create_poppler_quads_from_annot_quads() (fdo#76504).
  + utils: pdftohtml: Fix typo in manpage.
  + qt4: Fix some kinds of OCG models.
- Changes from version 0.25.2:
  + core:
  - Tagged-PDF support.
  - Open some broken files (fdo#75232).
  - Fix crashes on broken files.
  - Fix regression parsing some broken files (kde#329600).
  - Improve compilation under Win 8 with Visual Studio 2012
    (fdo#73111).
  - PSOutputDev:
    . Ensure paper size takes into account rotation (fdo#72312).
    . Fix DocumentMedia/Page/Media/PageBBox DSC comments.
    . Use crop box as page size.
    . Remove origpagesizes mode and make -origpagesizes an alias
    for -paper match.
    . Only change paper size when different to previous size.
    . Ensure there is always a page size in the output.
    . Fix regression when creating level1 PS (fdo#75241).
  - CairoOutputDev: Clip to crop box (bgo#649886).
  - Splash:
    . Blend usage in PDF with spot colors casue random
    output (fdo#74883).
    . Fix off by one that caused crash in a file (fdo#76387).
  - Make sure number of least objects in hints table is valid
    (fdo#74741).
  - Limit numeric parsing of character names (fdo#38456).
  + glib:
  - Tagged-PDF support.
  - Annotation improvements.
  - Install error callback (fdo#73269).
  - Fix gobject-introspection warnings.
  - demo: Fix performance in text markup annotations.
  - Increase gtk3 dependency.
  + qt4:
  - Improve naming of internal export/import macros.
  - Add GCC visibility export attributes.
  - Expose document-supplied text direction.
  + qt5:
  - Improve naming of internal export/import macros.
  - Add GCC visibility export attributes.
  - Expose document-supplied text direction.
  + utils:
  - pdftocairo: Ensure page size and crop box works the same as
    pdftops.
  - Fix TIFF writting in Windows (fdo#75969).
  + buildsystem:
  - Learn about automake 1.14.
  - Do not define -ansi (fdo#72499).
  - cmake:
    . Install JpegWriter.h depending on libjpeg
    . Use c99 for the c compiler.
- Changes from version 0.25.1:
  + core:
  - GooString format:
    . Added some tests + improved documentation.
    . Fixed bug with printing LLONG_MIN.
  - Regression test improvements.
  + qt4:
  - Arthur backend font rendering improvements.
  - Test program to save to file.
  + qt5:
  - Arthur backend font rendering improvements.
  - Improve detection of Qt5 moc (fdo#72744).
  - Test program to save to file.
  + utils:
  - pdfunite:
    . Work even if there's a single file given.
    . Do not lose fonts when merging some files.
- Changes from version 0.25.0:
  + core:
  - Annotation improvements.
  - Tagged PDF work.
  - Improve speed on some files using ICC color space.
  - Use ICC profile in OutputIntents (fdo#34053).
  - Limit use of ZapfDingbats character names (fdo#60243).
  - Splash: correction for knockout transparency groups.
  - Regression test improvements.
  + utils:
  - pdftoppm: Added thinlinemode option setting.
  - pdfinfo:
    . Indicate if pdf contains javascript.
    . Add option to print out javascript.
  - pdfimages:
    . Print size, ratio, and ppi.
    . More image output format support.
  - pdfseparate: allow zero-padded pagespecs.
  + glib:
  - Annotation improvements.
  - Add API to get text, text layout and text attributes for a
    given area.
  - Demo improvements.
- Bump soname following upstream changes.
* Wed Feb 26 2014 dap.darkness@gmail.com
- bnc#864299 was fixed: libpoppler-devel includes poppler-cpp.pc
  and libpoppler-cpp.so (symlink to libpoppler-cpp.so.*).
  So libpoppler-devel must require libpoppler-cpp.
* Sun Jan 19 2014 zaitor@opensuse.org
- Update to version 0.24.5:
  + core: Fix crash due to wrong formatting of error message
    (kde#328511).
* Sat Dec  7 2013 zaitor@opensuse.org
- Update to version 0.24.4:
  + core:
  - Fix regression in broken endstream detection (fdo#70854).
  - Catalog: sort entries of NameTrees to make sure lookup works
    (fdo#26049).
  - Don't infinite loop if reading from GooFile::read fails
    (fdo#71835).
  + utils:
  - pdftotext:
    . Do not close stdout (fd0#71639).
    . Silence warning for may be used uninitialized variable
    (fdo#71640).
    . Escape the text of the xml headers.
  - Warn the user if he provides a wrong range
  + qt4:
  - Fix typo in xml API (fdo#71643).
  + qt5:
  - Fix typo in xml API (fdo#71643).
- Bump soname following upstream changes.
* Tue Oct 29 2013 zaitor@opensuse.org
- Update to version 0.24.3:
  + core:
  - PSOutputDev: Fix PFB font embedding (fdo#69717).
  - CairoOutputDev: Do not set an invalid matrix in drawImage()
    (fdo#70085).
  + qt4:
  - Don't crash if getXRef()->copy() fails.
  + qt5:
  - Don't crash if getXRef()->copy() fails.
  + utils:
  - pdfseparate: Allow only one %%d in the filename (fdo#69434).
- This version fixes bnc#847907; CVE-2013-4473 and  CVE-2013-4474.
* Sat Sep 28 2013 zaitor@opensuse.org
- Update to version 0.24.2:
  + core:
  - Windows: Fix CreateFile fails with ERROR_SHARING_VIOLATION
    (fdo#69597).
  + utils:
  - pdfseparate: improve the path building.
  - pdftocairo: check file opening failure in beginDocument().
* Fri Aug 30 2013 zaitor@opensuse.org
- Update to version 0.24.1:
  + core:
  - SplashOutputDev: use getRGBLine images if available
    (fdo#66928).
  - SplashOutputDev: Don't copy bitmap if we don't need to.
  - PSOutputDev: Fix regression in -eps -level1sep rendering
    (fdo#68321).
  - Fix crash in malformed file. Use copyString instead of strdup
    where memory is freed with gfree (fdo#67666).
  + utils:
  - pdfdetach: don't mention xpdfrc.
  - pdftotext: Fix -bbox with stdin as input (fdo#45163).
  - pdftohtml: Fix jpeg image export (fdo#48270).
  - pdfimages: Fix typos in man page.
  + glib:
  - demo: Remove GTK_DISABLE_DEPRECATED compilation flag.
  + qt4:
  - Fix small typo in documentation.
  + qt5:
  - Fix small typo in documentation.
* Thu Aug 29 2013 hrvoje.senjan@gmail.com
- Adjust spec files so they build correctly Qt5 port, building of
  it is still disabled
* Tue Jul 30 2013 zaitor@opensuse.org
- Update to version 0.24.0:
  + TextOutputDev: Do not draw ligatures more than once when
    selected (fdo#9001).
  + PSOutputDev: Make some pdftops conversions much faster.
  + PSOutputDev: Initialize t3FillColorOnly.
  + SplashOutputDev: Fallback to 1x1 bitmap if we fail to create
    the real size.
- Bump soname following upstreams changes.
* Wed Jul 24 2013 zaitor@opensuse.org
- Update to version 0.23.4 (0.24 beta 4):
  + core:
  - TextOutputDev: clip the selected text rendering to the
    selection box (fdo#66983).
  - CairoImageOutputDev: Fix the bounding box of saved images.
  + build system:
  - Improve linking against pthreads.
- Bump soname following upstreams changes.
* Tue Jul  9 2013 dimstar@opensuse.org
- Update to version 0.23.3 (0.24 beta3):
  + core:
  - Annotation improvements.
  - Fix crashes on malformed files.
  - TextSelectionPainter: Draw glyphs after selection background.
  - TextOutputDev: add a method to TextPage to get the selection
    as a list of words.
  + qt5:
  - Initial Qt5 port.
  + qt4:
  - Windows compile fixes.
  - Demo: Allow the choose the page rotation.
  + build system:
  - Fix mingw build.
  - Minor autotools fixes.
- Prepare spec file to build for Qt5 once it appears in Factory.
- Change poppler_data_version to 0.4.6, which is the version
  provided since 2012. Note that this does not actually make a
  different, as it's used in a Recommends, which does not care
  much about the version.
* Sun Jun 23 2013 zaitor@opensuse.org
- Update to version 0.22.5:
  + core:
  - PSOutputDev: Make sure that Title: doesn't contain \n or \r
    (fdo#63862).
  - Fix slowlyness reading malformed files (fdo#46703).
  - Fix infinite loop while feeding wrong data in stdin
    (fdo#64967).
  - Fix crash on malformed file (fdo#65221).
  - Fix mismatched delete (fdo#65553).
  + qt4: Fix mismatched delete (fdo#65551).
  + utils: pdftohtml: Fix memory leak.
* Sat Jun  1 2013 zaitor@opensuse.org
- Update to version 0.22.4:
  + core:
  - Always consider a softmask transfer function (fdo#63587).
  - Fix crash on malformed files (fdo#63190).
  - Splash: Fix compilation with fixed point mode enabled.
  + utils: Fix crash on some files (fdo#63909).
  + qt4: Fix name decoding of some attachments (kde#307786).
  + build system: Fix compilation with mingw-w64 compiler.
- Bump soname following upstream changes.
* Mon Apr 15 2013 zaitor@opensuse.org
- Update to version 0.22.3:
  + core:
  - Check order bounding box values in tiling pattern
    (fdo#62369).
  - CairoImageOutputDev: Don't change image interpolation when
    printing (fdo#62418).
  - TextOutputDev: Set text matrix when painting selection
    (fdo#61042).
  - Only write the file once when saving (fdo#62739).
  - Fix for complete rewrites in repaired files.
  - Fixlet regarding spec interpretation for Link Zoom value.
  - Fix typos in man pages.
  - Fix compile when not using libjpeg.
  + glib:
  - Always start from the beginning when starting a new search on
    a page (fdo#59972).
  + qt4:
  - Fix crash in files with LinkRendition (kde#317710).
  + build system:
  - Small cmake improvements.
- Bump soname following upstream changes.
* Tue Mar 12 2013 idonmez@suse.com
- Update to version 0.22.2:
  + core:
  - Correct rendering of underline and strike out annotations
    (fdo#61518)
  - Workaround broken jpeg stream definitions (fdo#61994)
  - SplashOutputDev: Restore CTM on early exits (fdo#61413)
  - SplashOutputDev: Make sure we don't try to paint in x < 0
    (kde#315432)
  - Fix latin page labels. (fdo#61034)
  - Fix minor valgrind warning
  + utils:
  - pdfimages: Fix extraction of some images (fdo#61168)
  + build system:
  - Fix the build with automake-1.13
* Mon Feb 25 2013 zaitor@opensuse.org
- Update to version 0.22.1:
  + core:
  - Fix crash in some pdf files when extracting text (fdo#59561).
  - Fix crashes in wrongly formed files.
  - Fix wrong warning when opening some files (fdo#58966).
  + build system: Improve autoconf jpeglib.h detection (fdo#59186).
- Following security bugs are fixed: CVE-2013-1788, CVE-2013-1789,
  CVE-2013-1790 (bnc#806793)
* Fri Jan  4 2013 hrvoje.senjan@gmail.com
- Update to version 0.22.0:
  + core:
  - Fix crash in invalid files that define a <= 0 bits per image
    value
  - Fix a few issues in JPX decoding when not using OpenJPEG
  - TextOutputDev: Use page size for max value in
    TextPage::visitSelection
  - Fix typo in error message
  + utils:
  - Fix pdfunite regression (fdo#358569)
  - Demo fixes and improvements
  + misc:
  - pdf-inspector improvements
* Tue Dec 18 2012 zaitor@opensuse.org
- Update to version 0.21.4:
  + core:
  - SplashOutputDev: Fix crash when rendering in monochrome mode
  - SplashOutputDev: Fix line widths in monochrome mode
    (fdo#57294)
  - PSOutputDev: Fix crop on EPS conversion (fdo#30692)
  - TextOutputDev: Fix minor logic mistake
  - Fix assert on some malformed files (fdo#58257)
  - Move #include "jpeglib.h" into .cc file (fdo#57687)
  - Filter text that may end up being written to the shell
  - Fix windows compile warnings
  + glib:
  - Add poppler_annot_set_flags (fdo#58015)
  - Demo fixes and improvements
  + qt4:
  - Fix check_lexer on 32-bit systems
- Changes from version 0.21.3:
  + core:
  - Splash: Implement bilinear image scaling (fdo#22138)
  - CairoOutputDev: Update fill and stroke color in startPage
    (fdo#54526)
  - Fix GooString::insert()
  - Allow large chars in TextPage
  - Fix crash on ActualText::end
  - Don't use memcpy to copy classes
  - Fix warnings
  + glib:
  - Check if words end with spaces (fdo#54504)
  - Ensure text is only computed on first render
  - Fix warnings while generating introspection file
  - Fix returns tag in PopplerAttachmentSaveFunc api doc
  - Minor demo fixes
- Changes from version 0.21.2:
  + core:
  - CairoOutputDev: make drawImage work with images > 32767 in
    width/height (fdo#56858)
  - CairoOutputDev: Fix soft mask when image resolution != smask
    resolution (fdo#57070)
  - CairoOutputDev: Fix crash in CairoImageOutputDev with
    setSoftMaskFromImageMask (fdo#57067)
  - Remove a check on fonts that we don't need (fdo#56753)
  - Misc code cleanups
  + utils:
  - pdftocairo: Add tiff output support (fdo#57006)
  - pdfunite: Fix -v (fdo#56817)
  - Misc code cleanups
* Fri Nov  9 2012 hrvoje.senjan@gmail.com
- Update to version 0.21.1:
  core:
  * Annotation improvements
  * Form improvements
  * CairoImageOutputDev: Support parameterized Gouraud shading (Bug #56463)
  * UTF validation fixes
  * Do not call drawing routines if we don't need non text (Bug #54617)
  * Fix Memory leak in CharCodeToUnicode (Bug #54702)
  qt4:
  * Make LinkRendition properties available (Bug #55378)
  * Accessors for FormWidgetChoice::editChoice
  * Implement overprint
* Sun Oct 14 2012 zaitor@opensuse.org
- Update to version 0.21.0:
  + core:
  - Support the modification of files with Encrypt
  - Annotation improvements
  - Form improvements
  - Splash: Implement DeviceN support
  - Splash: Avoid bogus memory error for tilingPattern
  - TextOutputDev: Allow multiple fonts in a TextWord
  - Kill the concept of base dir
  - PSOutputDev: Always write HiResBoundingBox (fdo#53159)
  - Convert UTF-16 to UCS-4 when reading toUnicode cmap
  - GooString formatting: add support for uppercase hexadecimal
  - Use error() instead of fprintf(stderr, ...) in
    Annot::layoutText
  - poppler-config.h: remove WITH_FONTCONFIGURATION_* macros
  + glib:
  - Annotation improvements
  - Add poppler_page_remove_annot()
  - Add poppler_document_new_from_stream
  - Add poppler_document_new_from_gfile
  - Add poppler_page_find_text_with_options (fdo#2951)
  - Demo improvements
  - Port tests and demo to GTK+3
  + qt4:
  - Add accessor methods for movie poster information
  - Make 'additional actions' available in Annotation API
    (fdo#53589)
  - Add whole-page search method to Poppler::Page
  - Small changes in tests
  + utils:
  - pdftohtml: Make the output more xhtml compliant
  - pdftohtml: Add -fontfullname. (fdo#49872)
  - pdftohtml: Do not invoke gs anymore
  + build system:
  - Add the possibility of using lcms1 even if lcms2 is installed
  - Remove extra fontconfig CFLAGS and LIBS
- Changes from version 0.20.4:
  + core:
  - Improvements regarding embedded file handling. (KDE#306008)
  - Fix opening some broken files (fdo#14303)
  - Fix memory leaks
  - Fix crashes in various broken files
  - Refine warning to only complain when really needed
  - Remove function declared but not implemented
  - Remove execution permissions from a header file
  + qt4:
  - Improvements regarding embedded file handling. (KDE#306008)
- Bump sonames following upstream changes.
* Fri Sep  7 2012 zaitor@opensuse.org
- Update to version 0.20.3:
  + core:
  - If NULL, NULL fails as password try EMPTY, EMPTY before
    failing (Bug #3498)
  - SplashOutputDev:
    . Fix bogus memory allocation size in
    Splash::arbitraryTransformImage (Bug #49523)
    . Fix segfault when scaleImage returns NULL (Bug #52488)
    . Blend mode enhancements for CMYK
  - PSOutputDev:
    .  Fix conversion when creating multiple strips (Bug #51982)
    .  Fix Bitmaps in level2sep or level3sep (Bug #52384)
    . Fix DeviceN images with alternate Lab colorspace in level 3
    PostScript (Bug #51822)
    . Make sure xScale and yScale are always initialized
    (Bug #52215)
  - Unify poppler-config.h includes in core "installed" headers
    (Bug #52193)
  - Replace c++ style includes with c style ones (Bug #52426)
  + utils:
  - pdfseparate: Return 0 on success.
- Bump poppler_soname to 27, following library soversion change.
* Tue Aug 21 2012 cfarrell@suse.com
- license update: GPL-2.0 or GPL-3.0
  poppler has a dual license (either GPL-2.0 or GPL-3.0) and emphasise that
  it does not use "or later"
* Sun Jul 29 2012 iacobcatalin@gmail.com
- Update to version 0.20.2 (bnc#774627):
  + core:
  - Copy resources content defined in the pages dict on save (Bug #51369)
  - PSOutputDev:
    . Correct %%%%DocumentCustomColors (Bug #51479)
    . Fix handling of DeviceN images in level 3 PostScript (Bug #51548)
    . use setoverprintmode only if rip knows it
  - Fix crash in malformed documents
  - Remove unnecesary transparency group handling in splash (Bug #13487)
  - Include substitute font name in system font cache (Bug #49826)
  - Fix logic on SplashBitmap::writeImgFile
  + qt4:
  - Do not hang on malformed /Annots objects (Bug #51361)
  - Make TextAnnotation constructor public
  - Fix saving of default TextAnnotation to xml
  - Keep page rotation into account when normalizing annotation coords
  + glib:
  - Fix memory leak when document fails to load
  - Make sure password is always converted to latin1
  - Fix typo in documentation
  + build system:
  - Distribute cmake/modules/FindLCMS2.cmake (Bug #49818)
  + utils:
  - pdftohtml:
    . Determine if font is bold or italic based on FontDescriptor (Bug #49758)
  - pdfseparate:
    . Syntax fixes in the man page
* Mon May 14 2012 vuntz@opensuse.org
- Change pkgconfig(lcms) to pkgconfig(lcms2) since poppler 0.20 now
  supports lcms2.
* Thu May 10 2012 badshah400@gmail.com
- Update to version 0.20.0:
  + Core:
  - Merge Xpdf 3.03
  - Annotation improvements
  - CairoOutputDev:
    . Fix regression caused by mesh gradients
    . Use correct userfont font bbox (fdo#48399)
    . Fix paintTransparencyGroup when both mask and fill opacity
    are required (fdo#48453)
    . Ensure 0 width lines with stroke_adjust are aligned
    . Only align stroke coords for horizontal and vertical lines
    (fdo#48318)
    . Fix stroke pattern with transparency group (fdo#48468)
    . Update cairo mesh pattern to 1.12 api
    . Fix some transparency issues (fdo#47739)
    . Fix regression in some shadings
    . Avoid setting huge clip area when printing (fdo#44002)
    . Fix test for rotation (fdo#14619)
    . Don't read inline image streams twice (fdo#45668)
    . Set mask matrix before drawing an image with a mask
    (fdo#40828)
  - SplashOutputDev:
    . Implement Overprint
    . Fix slow rendering of pdf with a lot of image masks in
    pattern colorspace
    . Fix rendering of knockout groups (fdo#12185)
    . Fix cmyk transfer bug (fdo#49341)
  - PSOutputDev: Implement Overprint
  - TextOutputDev: Don't add newline to last line extracted by
    TextSelectionDumper (fdo#45955)
  - Add support for lcms2
  - More compatible file writing
  - CJK font improvements
  - ttc<->ttf fallback is expected for CJK font list in for
    Windows (fdo#48046)
  - Improve font matching for non embedded fonts
  - Fix typos glyph names in truetype 'post' table standard mac
    ordering
  - Fix page labels to not have a null character at the end
  - Fix logic error in Rendition parsing code (fdo#47063)
  - Minor API changes to SplashOutputDev (fdo#46622)
  - Expand glyph name ligatures such as "ff", "ffi" etc to
    normal form (fdo#7002)
  - Use an Identity CharCodeToUnicode for Adobe-Identity and
    Adobe-UCS collections (fdo#35468)
  - Update glyph names to Unicode values mapping (fdo#13131)
  - Only use Hints table when there are no parse errors
    (fdo#46459)
  - Fix crash in JBIG2Stream decoding
  - Fix crashes in broken documents
  - Expose POPPLER_VERSION in poppler-config.h
  - Reconstruct xref table if xref needed but missing
    (fdo#40719)
  - Fix getFullyQualifiedName with unicode field names
    (fdo#49256)
  - Bring back the Outputdev::begin/endMarkedContent virtuals
  + Qt4:
  - Annotations can now be modified/added/removed
  - Form support improvements
  - Support for LinkMovie object (fdo#40561)
  - Support for Media Rendition
  - Add the option of PSConverter creating EPS
  - Convert propertly unicode encoded field qualified names
  + Glib:
  - Add poppler_fonts_iter_get_encoding
  - Add poppler_fonts_iter_get_substitute_name
  - Demo improvements
  - Update gtk-doc makefile and m4 file
  - Fix typos in documentation
  - glib: Use delete[] to free array allocated with new[]
    (fdo#48447)
  + Utils:
  - pdftohtml:
    . Fix crash when the destination file does not exist
    . Add producer and version to xml output
    . Fix the mask inversion for PNG
    . Extract mask images even if they are not JPEG (fdo#47186)
    . Flip images if they need to (fdo#32340)
    . Add possibilty of controlling word breaks percentage
    (fdo#47022)
    . Output images in -xml mode if no -i option is specified
    . Get rid of static data members; merge duplicated jpeg
    dumping code
    . Be more consistent generating the outlines
    . Generate outlines in pdftohtml in -xml mode (fdo#56993)
    . Combine UTF16 surrogate pairs (fdo#46521)
  - pdffonts:
    . List the encoding of each font. (fdo#46888)
    . Add -subst option to list the substitute font name and
    filename
  - pdfinfo:
    . Report page rotation
    . Decode utf-16 surrogate pairs
  - pdftotext: Add missing section heading to man page
  - pdftops: Fix -passfonts regression. (fdo#46744)
  - pdftoppm: Allow one of -scale-to-[xy] = -1 to mean the
    aspect ratio is to be preserved (fdo#43393)
  - pdftocairo: Allow one of -scale-to-[xy] = -1 to mean the
    aspect ratio is to be preserved
  - pdfseparate: Produce PDF/X conformant pdf pages if the
    original PDF was PDF/X conformant
  - pdfimages: Add -list option to list all images (fdo#46066)
  - Improve various manpages
  + Build system:
  - autotools:
    . Do not append "-ansi" to CXXFLAG, if "-std=XXX" is already
    specified.
    . Do not clear FREETYPE_CFLAGS, FREETYPE_LIBS before
    PKG_CHECK_MODULES()
    . Copying graphics library CFLAGS to cpp frontend Makefile.am
    . Print the cairo version required if not found (fdo#44619)
    . Print the glib version required if not found
    . Use pkgconfig to check for libopenjpeg (fdo#21789)
    . Replace openjpeg compile test with a version test
  - Minor cmake fixes
  - Add a configuration option for the test data dir
- Updated sonames for shared libraries in keeping with upstream
  package changes: poppler_soname is now 25, poppler_qt4_soname is
  now 4.
* Sun Mar  4 2012 asterios.dramis@gmail.com
- Enabled build requirement for openjpeg.
* Thu Feb 16 2012 vuntz@opensuse.org
- Update to version 0.18.4:
  + core:
  - CairoOutputDev:
    . Restore temporary clip used in CairoOutputDev::fill when
    painting a mask
    . Ensure paintTransparencyGroup uses same ctm as
    beginTransparencyGroup (fdo#29968).
    . Use fabs when comparing the transformed line width
    (fdo#43441).
    . Remove unused variable in CairoFontEngine.cc (fdo#45442).
  - SplashOutputDev: Do not use 50Kb of stack in
    SplashXPath::addCurve (fdo#44905).
  - JpegWriter: set image parameters after jpeg_set_defaults()
    (fdo#45224).
  - OpenJPEG decoder: Set
    OPJ_DPARAMETERS_IGNORE_PCLR_CMAP_CDEF_FLAG if you have it
    (fdo#43414).
  - Lexer: convert integer to real when overflow occurs
    (fdo#45605).
  + glib:
  - Various minor introspection and documentation improvements
    (fdo#44790).
  - Fix return values (fdo#45440, fdo#45441).
  - gtk-doc improvements (fdo#45549).
  - Introspection improvements (fdo#45455).
  + qt4:
  - remove non-existing 'qt' include dirs
  + utils:
  - HtmlOutputDev:
    . Proper unicode support when dumping PDF outline
    (fdo#45572).
    . Fix leaks (fdo#45805).
    . Close li tags in generated outlines (fdo#45807).
  - man pages: fix minor issues with hypens and %%
  + build system:
  - automake: Link to lcms if needed
  - automake: Fix build for builddir != srcdir (fdo#45434).
  - automake: Improve moc detection when cross compiling
  - Fix build with latest mingw-w64 headers (fdo#45407).
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 0.18.3:
  + core:
  - Do not fail if we are trying to save a file with Encrypt that
    has not been modified (kde#288045)
  - Include .otf fonts when finding substitute fonts (fdo#44412)
  - Fix stack overflow in PDFDoc::markObject() (fdo#44660)
  - Include strings.h as we use memcpy (fdo#43558)
  + utils:
  - pdfunite: Properly initialize globalParams (fdo#44659)
  - pdfseparate: Properly initialize globalParams
  - Fix iniliazialization of GooString arguments
  + build system:
  - autoconf: Check for cairo-ft and other cairo backends
    (fdo#43969)
- Add explicit pkgconfig() BuildRequires, following upstream
  changes, for: cairo-ft, cairo-pdf, cairo-ps, cairo-svg.
* Mon Jan  9 2012 vuntz@opensuse.org
- Split typelib file into typelib-1_0-Poppler-0_18 subpackage.
- Add typelib-1_0-Poppler-0_18 Requires to libpoppler-glib-devel
  subpackage.
* Wed Jan  4 2012 vuntz@opensuse.org
- Update to version 0.18.2:
  + core:
  - Fix leak in GooString when resizing to a smaller string
  - Fix crash if failing to parse the colorspace (fdo#42793)
  - Make GfxColorSpace::parse accept dicts
  + qt4:
  - Use PDFDoc(wchar_t *, ...) on Windows (fdo#35378)
  - Add missing include
  - Minor fixes in documentation
  + utils:
  - pdftocairo: Fix crash when rendering only odd/even pages in a
    printing format
  + build system:
  - Fix pkg-config files
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 0.18.1:
  + core:
  - PSOutputDev:
    . Output PS that does not confuse libspectre
    . Fix tiling pattern fill matrix (fdo#41374)
    . Emit non repeating patterns just once
    . Fix uncolored tiling patterns (fdo#41462)
  - CairoOutputDev:
    . Fix crash when using poppler_page_get_image()
    . Fix various setSoftMask bugs (fdo#41005)
  + utils:
  - pdftocairo:
    . Flush/close files one we are done using them
    . Compile on Windows
  + build system:
  - CMake:
    . Fix typo in option description
    . Correctly include fontconfig include dir
  - Remove poppler-cairo dependency from poppler-glib pkg-config
    file
  + qt4:
  - Minor fixes in documentation
- Bump poppler_soname to 19, following library soversion change.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 0.18.0:
  + core:
  - Fix small memory leak when dealing with marked content
  - Remove DCTStream::getRawStream since Stream::getNextStream
    does the same
  + utils:
  - Rename pdfmerge to pdfunite
  - Rename pdfextract to pdfseparate
  - pdfseparate: Complain if %%d is not present and it should
  - Add pdfseparate and pdfunite man pages
  + build system:
  - Minor cleanup in regarding removed qt code
- Bump poppler_soname to 18, following upstream soversion change.
* Fri Sep 16 2011 vuntz@opensuse.org
- Update to version 0.17.4:
  + core:
  - SplashOutputDev: Compile when defining USE_FIXEDPOINT
  - PNGWriter: Compile with libpng >= 1.5.0
- Bump poppler_api define since the typelib file is now versioned
  0.18.
* Sat Sep 10 2011 vuntz@opensuse.org
- Update to version 0.17.3:
  + core:
  - PSOutputDev:
    . Use Patterns for tiling fill when PS level >= 2
    . Avoid using /PatternType if only one instance of the
    pattern is used
    . Add poppler version as comment in the file
  - CairoOutputDev:
    . Set mime data for soft masked images (fdo#40192)
    . Assume printer pixel size is 1/600" when stroking 0 width
    lines (fdo#39067)
    . Use cairo_show_text_glyphs() when printing
    . Fix stroke patterns (fdo#11719)
    . Fix unique id mime data
    . Fix stroking of very thin lines
    . Align strokes when Stroke Adjust is true and line
    width <= 1 (fdo#4536)
  - TextOutputDev: Add TextFontInfo::matches()
  - Improve PNGWriter
  - Rework writing of PDF files
  + utils:
  - Introduce pdftocairo: utility for creating
    png/jpeg/ps/eps/pdf/svg using CairoOutputDev
  - Introduce pdfextract: utility to extract PDF pages
  - Introduce pdfmerge: utility to merge PDF files
  - Fix compilation warning
  - pdftohtml: Support text rotation (fdo#38586)
  - Update SEE ALSO section of man pages
  + glib:
  - Add poppler_page_get_text_attributes()
  - Add text attributes information to text demo
  + qt4:
  - Add a way to get the fully qualified name of a FormField
  - Minor documentation improvements
- Changes from version 0.17.2:
  + core:
  - EmbeddedFile improvements
  - Don't gmalloc(-1) upon ftell failure
  - Fix missing content in some pages (fdo#39637)
  - Improve selection of CJK fonts (fdo#36474)
  - SplashOutputDev:
    . Implement overprint
    . Render dots for 0 length dashed lines (fdo#34150)
    . Fix bad memory access when not using antialias (fdo#37189)
  - PSOutputDev:
    . Make level2sep and level3sep write cmyk instead of rgb
    . Make level1sep, level2sep and level3sep write gray instead
    of rgb for gray images
  - Fix numerical overflow in libopenjpeg JPXStream (fdo#39361)
  - Fix crash on truncated JPEG/DCT stream (fdo#36693)
  - Make sure the dict is a page dict (fdo#35925, fdo#39072)
  - Fix calculation of startXRefPos
  - Handle missing startxref properly (fdo#38209)
  - Parse the "Medium" modifier when asking fontconfig for a font
  - Header cleanup
  - Include cleanup
  - Define cleanup
  + glib:
  - Add missing permissions flags to PopplerPermissions
  - Add missing permission flags to info demo
  - Update gtk-doc.make
  - Add poppler_document_get_n_attachments()
  + utils:
  - pdftohtml:
    . Fix encoding of PDF document metadata (fdo#37900)
    . Fix vertical spacing issues  (fdo#38019)
  - pdftotext: Fix -htmlmeta to correctly output U+2019 in PDF
    metadata (fdo#37900)
  - pdftoppm: Implement overprint
  + qt4:
  - Rework EmbeddedFile internals
  - Fix possible crash in test
- Changes from version 0.17.1:
  + core:
  - Rework the way form fields tree is built
  - Cleanup unused parameters/variables
  + glib:
  - Add JavaScript actions
  - demo: Show javascript actions in actions view
  + qt4:
  - tests: Turn some assignments to bool into QVERIFY checks
- Changes from version 0.17.0:
  + core:
  - Splash:
    . Implement tiling patterns
    . Support slight hinting
    . Radial shading improvements
    . General speed improvements
  - Arthur: Add Hinting API
  - Cairo:
    . Implement Type 4,5,6,7 shadings using cairo mesh gradients
    . Use the new cairo unique id to set the surface id when
    printing
  - PS:
    . Add PS level1 non standard binary output option
    . Allow setting the rasterization resolution
  - Form support improvements
  - Annotation support improvements
  - General speed improvements
  - Add support for handling ViewerPreferences
  - Remove abiword output device
  + utils:
  - pdftoppm:
    . Add -singlefile option (fdo#32025)
    . Add TIFF output format support (fdo#32027)
  - pdftops:
    . Add PS level1 non standard binary output option
    . Allow setting the rasterization resolution
  - pdftoabw has been removed
  + glib:
  - Add poppler_form_field_get_action() (fdo#33174)
  - Remove GDK API
  - Remove test-poppler-glib
  - demo:
    . Add a tooltip with current selected character in text demo
    . Show the activation action of form fields if there's one
  + cpp:
  - Add TIFF output possibility
  - Add PNM output possibility
  + qt4:
  - Support slight hinting
  - Form support improvements
  + qt3:
  - The Qt3 frontend has been removed
  + tests:
  - Merge splash and cairo tests into a single gtk-test tool
- Drop poppler-pdftoabw-overflow.patch: the abiword output device
  got removed.
- Drop poppler-0.16.5-disable-demo.patch: we don't need it anymore,
  as we won't build the test program anyway.
- Bump the soname macros to follow upstream soversion changes.
- Add libtiff-devel BuildRequires: new dependency.
- Remove unneeded gtk-doc, gtk2-devel and libxml2-devel
  BuildRequires (GTK+ is only needed for a test tool).
- Remove pkg-config BuildRequires: by depending on glib, we know it
  will be there.
- Remove qt3-devel BuildReqiures: the Qt3 frontend has been
  removed.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: liblcms-devel, libpng-devel.
  + New ones: lcms, libpng.
- Add pkgconfig() BuildRequires that were brought in by gtk2-devel
  before: cairo, fontconfig, freetype2, gobject-2.0.
- Remove cairo-devel and libjpeg-devel Requires from
  libpoppler-devel: those are not needed.
- Remove libpoppler-devel, cairo-devel, glib2-devel and gtk2-devel
  Requires from libpoppler-glib-devel: the right Requires will
  automatically be added the pkgconfig() way.
- Drop libpoppler-qt and libpoppler-qt3-devel subpackages as the
  Qt3 frontend has been removed.
- Merge libpoppler-doc subpackage with libpoppler-glib-devel, as
  the documentation is only for the glib API. Add appropriate
  Provides/Obsoletes, and move the Provides/Obsoletes that
  libpoppler-doc had too.
- Remove call to autoreconf: it was only needed for one of the
  patches.
- Pass --disable-gtk-test: don't bother building the GTK+ test
  program.
* Fri Aug 12 2011 dmueller@suse.de
- remove requires on libdrm-devel
* Fri May 20 2011 idonmez@novell.com
- Add poppler-0.16.5-disable-demo.patch: disable glib demo, its
  using deprecated GTK+ functions
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 0.16.5:
  + core:
  - Fix a memleak in AnnotScreen::initialize
  - Properly initialize pageObjectNum to 0 (fdo#35925)
  + utils:
  - pdftotext: bbox coordinates are relative to MediaBox size,
    not CropBox size
  + cpp:
  - Fix page_transition::operator=
- Changes from version 0.16.4:
  + core:
  - Small improvements in Annot parsing
  + glib:
  - Add g_return macros to make sure index is correct in form
    field choice methods
  - Fix a crash when a choice form field has no items selected in
    glib-demo
  + utils:
  - Small fixes to the pdftohtml manpage
  - Fix copyright years
  + qt4:
  - Fix caption of push button fields
- Changes from version 0.16.3:
  + core:
  - Increase precision in PS output device
  - Workaround bug when converting pdf to ps with level1
    (fdo#31926)
  - Fix crash in Splash output device in some broken pdf
  - Fix infinite loop in some broken files
  - Fix rendering of some substituted fonts (fdo#34522)
  - Do not ask Freetype for 0x0 fonts in Splash output device
    (fdo#34602)
  - Don't assume y1 > y3 for points of a highlight annotation
    (bgo#643028)
  - Handle fontCIDType2OT when creating freetype font in Cairo
    output device (bgo#643273)
  - Fix crash in some pdf that use ICC color space (fdo#34357)
  + glib:
  - Don't use an uninitialized local variable in demo
  - Add some introspection markers
  + qt4:
  - Fix crash regression in unicodeToQString (again)
  + utils:
  - pdftotext: Do not crash when using -bbox
- Ship COPYING in poppler-tools subpackage. Fixes bnc#678887.
- Update poppler_soname as the soname has changed again.
* Wed Feb 23 2011 fcrozat@novell.com
- Update to version 0.16.2:
  + Core:
  - Fix text extraction for some files
  + qt4:
  - Fix crash regression in unicodeToQString
- Changes from version 0.16.1:
  + Core:
  - Fix colorspace issues in the Cairo backend (fdo#32746)
  - Remove declaration of function without implementation
  - Do not crash in case jpeg_create_decompress fails (fdo#32890)
  - Fix variable access mismatch (fdo#33063)
  - Fix converting some pdf to ps with -level1sep (fdo#32365)
  - Fix line selection, dont check y for Line selections
  - Include zlib header in PNGWriter.cc
  - Fix memleaks
  + glib:
  - Use NULL instead of FALSE for functions returning a pointer
  - Fix memory leak in poppler_page_get_text_layout() for pages
    with no text
  + qt4:
  - Fix unicodeToQString() to correctly decode the Unicode
    sequence
- Changes from version 0.16.0:
  + core:
  - Improve the correctness of radial shadings (fdo#32349)
  - Adapt the zlib-based FlateStream code to API changes
    (fdo#32065)
  - Make PreScanOutputDev be less agressive when deciding to
    rasterize (fdo#30107)
  - Fix some warnings in newer gcc in Splash backend
  - Fix the preliminary bbox/clip calculation in Splash backend
  - Use A1 instead of A8 for imagemask in the Cairo backend
  + utils:
  - Do not return 99 (or 1) with -h, -v and -printenc (fdo#32149)
  + build system:
  - Add more warning flags to the default gcc builds
  - Enable GObject introspection support in the cmake build system
- Changes from version 0.15.3:
  + core:
  - Improve rendering of radial shadings
  - Open a broken file (fdo#31861)
  - Correct parsing of linearization table (fdo#31627)
  - Find fonts inside patterns (fdo#31948)
  - Use a std::vector<char> instead of a var-length-array of
    chars
  - Fix crashes in broken files
  - Use sets instead of arrays for looking for duplicate fonts
  + cpp:
  - Include correction
  + utils:
  - pdffonts: Remove duplicated code
- Changes from version 0.15.2:
  + core:
  - Improve shadings and antialias in the Splash backend
    (fdo#30436)
  - Linearization improvements
  - Small improvements to the Arthur backend
  - Fix calculation of the size of some pages (fdo#30784)
  - Fix crashes in broken documents
  + qt4:
  - Add Page::renderToPainter() method
  - Add setDebugErrorFunction() method
  + cpp:
  - Add the hability to render pages to an image
  + utils:
  - Add -p flag to pdfimages
- Changes from version 0.15.1:
  + core:
  - Consider render value when colorizing text (fdo#2807)
  - Improve rendering of Shading Type 6 and 7
  - Improve dict lookup speed for big dicts
  - Fix multiple crashes in malformed PDF files
  - Fix memory leak in in malformed PDF files
  - Fix memory leak in the Catalog names
  - Fix uninitialized uses on DCTScanInfo
  - Fix a crash when drawing square/circle annots without a
    border (fdo#30580)
  - Only clip boxes to mediabox if we are at the page level
    (fdo#30784)
  - Do not omit the notdef glyph in the Splash backend
  - Fix a crash when redering documents with invalid type 3
    fonts in the Cairo backend
  - Form improvements
  - Add a method to get the PDF file identifier
  + glib:
  - Add more printing options to the API
  - Add a method to get the PDF file identifier
  - Add accessor for all PopplerDocument properties
  - Form improvements
  - Documentation improvements
  - Improvements to the demo
  + qt4:
  - Add a callback to know which page has been printed
  - Add a method to get the PDF file identifier
  - Optimize GooString to QString conversion
  - Update Doxyfile (enables .qch file for assistant)
  + utils:
  - pdftohtml: Add -s option to generate a single HTML page
  - pdftotext: Add -bbox option
  + cpp:
  - Add the possibility of loading a document from raw data
  - Add a method to get the PDF file identifier
  - Improve Unicode to ustring conversion
  - Documentation improvements
  - Update Doxyfile
- Changes from version 0.15.0:
  + core:
  - Remove exception support
  - Improve creation of Annotations
  - Fix failure to parse PDF with damaged internal structure.
    (fdo#29189, fdo#3870)
  - Add a way to access the raw text of a page
  - Speed improvements when reading multiple characters from a
    given Stream
  - Speed improvements in the Splash backend
  - Speed improvement in gray color space calculations
  - Speed improvement in ICC color space calculations
  - Speed improvement when reading some fonts
  - Make GBool a bool instead of an int
  + glib:
  - Add GObject introspection support
  - Improve creation of Annotations
  - Add a way to get the coordinates of each character of a page
  - Add a way to get the page label
  - Documentation improvements
  - Support password protected documents in the demo
  - Support for selection in the demo
  - Support for adding annotationss in the demo
  + qt4:
  - Add a way to access the raw text of a page
  - Recognize "Print" as named action
  - Documentation improvements
  + build system:
  - Improvements when build the glib frontend with CMake
  + utils:
  - pdftohtml: Use splash instead of external gs invocation to
    render the background
  - pdftohtml: Let the user specify the resolution of the
    background. (fdo#29551)
  + cpp:
  - Add a way to access the raw text of a page
- Changes from version 0.14.3:
  + core:
  - Tell Windows we are writing/reading binary data from
    stdout/stdio (fdo#29329)
  - Fix crash when parsing some Movie elements (kde#249586)
- Bump soname for glib / cpp / qt / qt4 libraries
- Add gobject-introspection-devel BuildRequires to enable
  introspection support.
* Thu Nov 11 2010 coolo@novell.com
- own parent directories for poppler-qt
* Sat Oct  9 2010 vuntz@opensuse.org
- Update to version 0.14.4:
  + core:
  - Set initial state of optional content groups based on
    BaseState field
  - Fix multiple crashes in malformed PDF files
  - Fix memory leak in in malformed PDF files
  - Fix memory leak in the Catalog names
  - Fix uninitialized uses on DCTScanInfo
  - Fix a crash when drawing square/circle annots without a
    border (fdo#30580)
  + glib:
  - Fix layers array generation when it contains multiple arrays
  - Fix a crash when building layer actions (fdo#30106)
* Sat Sep 11 2010 vuntz@opensuse.org
- Update to version 0.14.3:
  + core:
  - Tell Windows we are writing/reading binary data from
    stdout/stdio (bgo#29329)
  - Fix crash when parsing some Movie elements (kde#249586)
* Thu Aug 19 2010 vuntz@opensuse.org
- Update to version 0.14.2:
  + core:
  - Fix rendering of some documents involving tilingPatternFill
    in the cairo output device
  - Improve rendering of some annotations
  - Handle ColorTransform in DCT streams when using libjpeg
    (fdo#28873)
  - Fix crash in the ps output device in some files (kde#246269)
  - Fix crash in some malformed files (fdo#28842)
  + build system:
  - Improve build on windows
  - Add uninstalled .pc file support when using autoconf
  + glib:
  - Fix a crash when a layer doesn't have a name (fdo#28842)
  + utils:
  - Fix padding of names in pdftoppm
- Bump poppler_soname from 6 to 7.
* Thu Jul 15 2010 dimstar@opensuse.org
- Update to version 0.14.1:
  + Core:
  - fdo#26759: Add ObjectStream caching, makes opening some files
    ten times faster
  - fdo#28480: Fix crash when writing to negative coordinates
  - Check objects are the type we want them to be when parsing
    GfxICCBasedColorSpace
  - Optimize Splash::compositeBackground
  - Optimize color space calculations by using sqrt instead of
    pow 0.5
  - Fix crash in JBIG2Stream with malformed documents
  + build system:
  - Make sure we ship two needed cmake files
  - Do not distribute glib/poppler-features.h and
    poppler/poppler-config.h
  - Improve compilation with Sun Studio
  - Fix linking of the cpp frontend when using autotools
  + glib:
  - fdo#28588: Fix links/annots area for some documents
  - fdo#27927: Fix poppler_page_find_tex() when called more than
    once
  + utils:
  - Add -cropbox to pdftoppm manual
* Thu May 20 2010 coolo@novell.com
- fix last change
* Mon May 17 2010 coolo@novell.com
- Split out qt bindings in a spec file, to speed up build.
* Thu Dec 24 2009 vuntz@opensuse.org
- Update to version 0.12.3:
  + core:
  - Be more lenient with /Decode key on images. fdo#17439
  - Correctly initialize fileName in LinkGoToR. fdo#25221
  - Improve the reconstruction of the XRef for broken files
  - [Cairo backend] Do not crash on malformed files. fdo#24575
  - Accept Fontname if FontName is not present. kde#217013
  - Make PSOutputDev code a bit more resilient
  - Fix writing of null objects. fdo#25465
  - [Cairo backend] Fix crash in some documents. bgo#603934
  - Correctly initialize profileCommands in Gfx constructor
  + build system:
  - Check for openjpeg in the C++ part as it uses bool in the
    header. fdo#25103
* Fri Dec 18 2009 jengelh@medozas.de
- Package documentation as noarch
* Sat Dec  5 2009 vuntz@opensuse.org
- Update to version 0.12.2:
  + core:
  - Fix a memory leak when converting to PostScript
  - Fix crash when reading a font fails. fdo#24525
  - Make the ICC cache per page instead of global. fdo#24686
  - Do not accept negative interval lengths in the page labels
    tree. fdo#24721
  - Do not crash on files Aspect of Movie objects are reals
    instead of integers. fdo#24733
  - Do not render patterns when using CairoImageOutputDev
  - Allow Transitions dictionary to be a Ref
  - Do not crash if jpeg_start_decompress fails. kde#214317
  + glib:
  - Fix CVE-2009-3607
  + qt4:
  - Use '.' in the annotations XML instead of the decimal
    separator of the current locale
- Drop poppler-CVE-2009-3607.patch: fixed upstream.
- Remove poppler_spec-prepare.sh, and instead integrate its code in
  pre_checkin.sh.
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 0.12.1:
  + core:
  - Fix compilation on some compilers
  - Only initialize the font list once in Windows32/MSVC
  - Do not crash on fonts without CharCodeToUnicode. fdo#24036
  - Fix regression due to not setting LC_NUMERIC anymore
  - Improve realibility for Streams with broken Length. fdo#6841
  - Write the Info into the trailer dict if there is one.
    fdo#24091
  - Do not crash when saving files that come from a stream
    without name. fdo#24090
  - Improve relability of the save function
  - Fix the Length value if it was wrong when saving
  - Fix includes for those using internal headers
  - Rework how hinting is used in the splash backend. It is
    disabled by default now
  - fix constructor of DCTStream when using internal decoder
  - Security fixes based xpdf 3.02pl4
  + qt4:
  - Add the possibility of setting wheter to use or not font
    hinting
  - Add a way for converters to return more exact errors they had
    when converting
  - Check the document is not locked when converting to PS
  + build system:
  - Compile on Cygwin
  - Use _WIN32 instead of WIN32. Bug #24259
  - Add the possibility to pass LIB_SUFFIX when using CMake
- Drop poppler-change-hinting-flags.patch: fixed upstream.
- Drop poppler-CVE-2009-3608.patch: fixed upstream.
- Update description of the packages to be less verbose without
  being less informative.
- Fix self-obsoletion rpmlint warnings: when we provide a version
  of a package, don't obsolete <= this version, but <.
* Tue Oct 27 2009 bili@novell.com
- Help Vincent submit these patches.
- Add poppler-CVE-2009-3607.patch: fix an integer overflow,
  bnc#546393, swampid#27127.
- Add poppler-CVE-2009-3608.patch: fix an integer overflow,
  bnc#543090, swampid#27127.
- Add poppler-pdftoabw-overflow.patch to fix string overflows in
  pdftoabw, bnc#537171, swampid#27127.
* Thu Oct  1 2009 wstephenson@suse.de
- Add patch to disable autohinting in the Splash backend, except
  when the bytecode interpreter is enabled, for consistency with
  other backends and better results
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 0.12.0:
  + core:
  - Fix printf format security warnings
  - Improve rendering of radial shadings. fdo#20238
  - Better fallback when there's a font type mismatch. fdo#17252
  - Do not crash on attachments without data stream. fdo#10386
  - Fix infinite loop in JBIG2Decoder. fdo#23025
  + build system:
  - Minimizes pkg-config dependencies for Qt frontends
  - Add automake 1.11 support
  - Use the newest automake found and not the oldest
  - Support AM_SILENT_RULES when using automake 1.11
  + utils:
  - Add common options to pdftoabw
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 0.11.3:
  + core:
  - Optimization in the Cairo renderer for some fonts
  - Do not apply masks when fill color space mode is csPattern in
    the Cairo renderer. fdo#22216
  - Check for overflow when parsing integers. fdo#23078
  - Do not save the font file twice for FreeType fonts in the
    Cairo renderer. fdo#20491
  - Use current fill_opacity when drawing images in the Cairo renderer
  - Fix alpha rendering in some files in the Splash renderer.
    fdo#22143, fdo#22152
  - Implement tiling patterns in the Cairo renderer
  - When converting a cm matrix to PS write 4 significant digits
    for numbers < 1 not 4 decimals. fdo#23332
  - Fix changing of locale, now poppler no longer changes LC_NUMERIC to "C"
  - Return PDF version as two integers instead of as a double
  + Qt4:
  - Addition of the Color Management API
  - Small fix to documentation
  - Fix backwards text search
  + utils:
  - Add the -png flag to pdftoppm to output to PNG
* Mon Aug  3 2009 vuntz@novell.com
- Update to version 0.11.2:
  + core:
  - Make DecryptStream return sane values for getPos(). fdo#19706
  - Fix bug when printing pdf with multiple page sizes in duplex
    mode
  - Initilize AnnotColot properly when the Array is not correct
  - Fix crash on some files with forms. fdo#22485
  - Fix crash in files with invalid embedded files. fdo#22551
  - Improve FileSpec attribute parsing
  - Cairo output device improvements. fdo#10942, fdo#18017,
    fdo#14160
  - Implement blend modes in cairo backend
  - Handle fontType1COT fonts in CairoFontEngine
  - Fix generation of PS for some files. fdo#18908
  - Don't use byte_lookup table when color space doesn't support
    getLine methods. fdo#11027
  - Fix rendering of PDF files with malformed patterns. fdo#22835
  - Add the possibility of disabling font substitution in
    pdftops. fdo#23030
  - Fix some radio buttons not being detected as such
  + glib:
  - Improvements to the demo
  + Qt4:
  - Improvements to the demo
  + build system:
  - Use gtkbuilder rather than libglade for some tests
  + utils:
  - Fix bug with noCrop parameter in pdftops
* Tue Jul 28 2009 coolo@novell.com
- disable build of gtk-doc subpackage, the auto* macros are broken
  (may be fixed in next beta)
* Tue Jul 28 2009 coolo@novell.com
- update to version 0.11.1:
  core:
  * Support colorizing text in pattern colorspace. Bug #19670 and #19994
  * Add the possibility of forcing no hinting of fonts in the Splash backend
  * Support multiple page sizes when converting to PS. Bug #19777
  * Also tokens with leading 00 when parsing the char to unicode map. Bug #22025
  * Improvements of rendering speed in documents using PS transformations a lot. Bug #21562
  * More work on Annotations support
  * Use Interpolate flag to decide whether applying image interpolation during rendering. Bug #9860
  * Handle Streams in CMap definitions. Bug #22334
  * Fix pdftops crash on file from KDE bug #174899
  * Fix PS generation in some files. Bug #20420
  * Do not create the GfxColorTransform if the lcms could not be created. Bug #20108
  * Give an error when using level1sep in pdftops without having CMYK support. Bug #22026
  * Kill support for specifying extension in openTmpFile. Bug #21713
  glib:
  * Add poppler_annot_markup_has_popup()
  * Hyphenate UTF-8 and UTF-16BE. Bug #21953
  * Use g_strerror instead of strerror. Bug #22095
  * Fix a crash when a destination points to an invalid page
  * Improvements to the demo
  Qt4:
  * Add LinkDestination::destinationName()
  * Do not try to resolve named destinations for GoTo links pointing to external documents
  * Add Page::thumbnail()
* Thu May 21 2009 pgajdos@suse.cz
- added GlobalParams::forceNoFTAutoHinting()
  - no-hinting.patch
  + force-no-hinting.patch
- this patch was upstreamed and should appear in next release
* Sun May 17 2009 vuntz@novell.com
- Update to version 0.11.0:
  + core:
  - Add initial support for color management
  - Remove case-insensitive matching of filenames in PDFDoc
    constructor
  - Fix extraction of some ActualText content
  - More work on Annotations support
  - Improve font rendering in Cairo output device
  - Fix bug in cairo backend with nested masks
  - Fix cairo luminosity smask rendering
  - Add optionally text support to Cairo output device
  - Add the possibility of setting the datadir on runtime
  - Return an error code instead of a boolean when saving
  - Make the font scanner more versatile
  - Small opimization in documents that use PostScriptFunction
    transforms
  - Minor optimization to Stream handling
  - Fix some compile warnings
  + glib:
  - Optional content support
  - More work on Annotations support
  - Improvements to the demo
  - Documentation improvements
  - Fix build when compiling with GTK_DISABLE_SINGLE_INCLUDES
  + Qt4:
  - Support URI actions for Table Of Contents items
  - Documentation improvements
  - Improvements to the demo
  - Add a FontIterator for iterating through the fonts of the
    document
  + utils:
  - Allow the use of cropbox in pdftoppm
  - Make pdftohtml output png images when the image stream is not
    a jpeg
  - Make pdftotext accept cropping options like pdftoppm
  - Support rendering non-square pixels in pdftoppm
  + build system:
  - Require Cairo 1.8.4 for the Cairo output device
  - Require CMake 2.6 when using the CMake build system
  - Optionally require libpng for pdftohtml
  - Optionally require libcms for color management
- Add liblcms-devel and libpng-devel BuildRequires.
- Rename libpoppler4 to libpoppler5.
* Fri Apr 17 2009 vuntz@novell.com
- Update to version 0.10.6:
  + core:
  - Fix problems that happen when parsing broken JBIG2 files.
    CVE-2009-0799, CVE-2009-0800, CVE-2009-1179, CVE-2009-1180,
    CVE-2009-1181, CVE-2009-1182, CVE-2009-1183, CVE-2009-1187,
    CVE-2009-1188
  - Fix parsing of incorrect border arrays. fdo#19761
  - Fix clip test for fonts. fdo#20950
  - Fix getGlyphAdvance to behave correctly on font size changes.
    fdo#20769
  - Misc build fixes
  + build system:
  - Fix the Qt4 version we need
* Mon Mar 30 2009 pgajdos@suse.cz
- poppler tools now provides and obsoletes xpdf-tools
* Tue Mar 24 2009 pgajdos@suse.cz
- disable hinting -- patch moved from xpdf splash copy to
  poppler's splash, reason:
    xpdf is going to use splash from poppler instead of own and
    unmaintained copy of splash. Without it, the xpdf rendering
    of pdf is very poor, when pdf font is small (e. g. document
    was zoomed out).
  * no-hinting.patch
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 0.10.5:
  + core:
  - Read the UF entry if present and prefer it over F in Filespec
    dictionary
  - Fix typo that was making CairoOutputDev crash on some files.
    fdo#17337
  - Make JBIG2Stream more robust to corrupt input data
  - Do not blindly follow loops parsing OutlineItem. fdo#18364
  - Set up the error manager before calling
    jpeg_create_decompress. fdo#20484
  - Check there is an optional content config before using it.
    fdo#20587
  - Fix rendering of some PDF with OpenType fonts. fdo#20605
  + build system:
  - Yet more support for build on windows
  - Use AC_CHECK_HEADER to find headers. fdo#20538
  - Check for pkgconfig before using it
  - General autotools improvements
* Wed Feb 25 2009 vuntz@novell.com
- Remove autoreconf & libtool workaround: we have no reason to call
  autoreconf.
- Remove -fno-strict-aliasing from CXXFLAGS: it's not needed for
  the build.
- Remove -fstack-protector: it's a default flag now.
- Remove QTINC and QTLIB definition: it's not needed for the build.
* Mon Feb 23 2009 dmueller@suse.de
- use the distro provided libtool
* Wed Feb 11 2009 vuntz@novell.com
- Update to version 0.10.4:
  + core:
  - Fix a memory leak when asking for a document-level JS
  - Do not crash in some PDF we do not parse correctly.
    (fdo#19702)
  - Fix crash on unexepcted form Opt value. (fdo#19790)
  + utils:
  - Fix pdfimages to extract i color components per pixel jpeg
    images. (fdo#19789)
* Thu Feb  5 2009 vuntz@novell.com
- Update to version 0.10.3:
  + core:
  - Fix a crash on documents with malformed outline. fdo#19024
  - Fix leak on AnnotScreen destructor. fdo#19095
  - Fix wrong PS generation when a large image is in Patterns.
    fdo#18908
  - Remove BaseFile.h it was never used. fdo#19298
  - Improve document saving
  - Fix PS generation of PDF with malformed font Length2
    definition
  - Fix a leak while parsing annotations
  - Fix rendering of some checkboxes
  + Qt4:
  - Fix positioning of Form rects on PDF with cropbox
  - Fix positioning of Annotation rects on PDF with cropbox.
    fdo#18558.
  - Small documentation improvements
  - Make Document::fonts() work when called more than once.
    fdo#19405
  + build system:
  - CMake: look harder for openjpeg
  - CMake: update the poppler core headers installation
  - Autotools: do not install Function.cc as it's not a header
  + Qt:
  - Fix deserialization of links right coordinate
- Changes from version 0.10.2:
  + core:
  - Fix a crash when selecting text in word mode
  - Fix a crash in some malformed documents (second argument of
    opMarkPoint is not a dictionary)
  - Ensure cairo font matrix is invertable. Fixes fdo#18254 and
    fdo#18429
  - Fix a memory leak (fdo#18924)
  + Qt4:
  - Fix deserization of links right coordinate
  + misc:
  - Fix build on Solaris 10 + Sun Studio 12
  - Compile with -pedantic
* Mon Nov 24 2008 sbrabec@suse.cz
- Updated to version 0.10.1:
  * Improvements in Optional Content support
  * Small fixes in ActualText and Form support
  * Fixed memory leaks and crashes
  * Invalid rendering fixes
  * Do not try to save documents that have Encryption
  * Fix rendering regression on some fonts
  * Documentation improvements
  * Improve memory usage of the cairo renderer
  * Initial JavaScript support
  * Added a JPEG2000 decoder
  * Emulate Adobe Reader behaviour on documents with duplicate keys
    in Dictionaries
  * Annotation improvements
  * Add the possibility of extracting embedded fonts
  * Added -listenc to pdfinfo and pdftotext
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.8.7:
  + Call error() when font loading fails
  + Be less strict parsing TTF tables (bfo#16940)
  + Fix crash due to uninitialized variable
  + Fix regression in Form rendering
  + Fix memory leak in the cairo backend
  + Qt 4 frontend:
  * Make the paper color setting working as it should
  * Make sure to use the correct page width/height for form
    widgets coordinates.
* Thu Aug 14 2008 sbrabec@suse.cz
- Updated to version 0.8.5:
  * Use a single global FT_Library in CairoOutputDev.
  * Do not limit CharCodeToUnicodeString to 8 characters
  * crash, bug and leak fixes
  * pdftohtml improvements
* Thu Jul 31 2008 dmueller@suse.de
- don't do poppler-devel rename for older distros
* Wed Jul  2 2008 maw@suse.de
- Add poppler-pagewidgets-null.patch (bnc#404955 and
  CVE-2008-2950).
* Wed Jun  4 2008 sbrabec@suse.cz
- Updated to version 0.8.2:
  * Add missing return in Object.h (fixes regression in 0.8.1)
- Backported annotation crash fixes from upstream (bnc#396634).
* Mon May 19 2008 maw@suse.de
- Provide pdftools_any in the -tools subpackage (bnc#378434).
* Mon May 12 2008 sbrabec@suse.cz
- Check for optional content before using it (bnc#389090,
  fdo#15899).
* Tue Apr 29 2008 sbrabec@suse.cz
- Updated to version 0.8.1:
  * Do not call FT_Done_Face on a live cairo_font_face_t as it
    might cause crashes
  * Do not take into account Colorspace resource subdictionary for
    image XObjects
  * Downsample 16 bit per component images to 8 bit per component
    so they render
  * Link to pthread when the system needs it
* Sat Apr 19 2008 schwab@suse.de
- Work around broken qt check.
* Fri Apr 11 2008 dmueller@suse.de
- remove obsoletes for older distros - it is just asking
  for trouble for buildservice users
* Thu Apr  3 2008 sbrabec@suse.cz
- Updated to version 0.8.0:
  * Public api changes
  * Many bug fixes
  * Better error handling
  * Check the document stream is seekable when opening it
  * Improve font matching not forcing default values onto
    Fontconfig
  * Add preliminary annotations support in the glib frontend
  * Initial Movie support in the core
  * Make GDK dependency optional in glib bindings
  * Really distribute CMake files as optional build tool
  * Initial Optional Content support in core and in the Qt4
    frontend
  * Saving support
  * Partial annotation support
  * Forms improvements
  * Add support for ActualText entries
  * Display characters outside of unicode BMP with TT font
  * CJK rendering fixes
  * Implement Adobe Glyph Naming convention for fonts
  * CMake as optional build tool
  * Better font scaling for non embedded fonts
  * Preserve PDF page labels when we output as postscript
* Thu Jan 31 2008 maw@suse.de
- Update to version 0.6.4:
  Qt4 frontend:
  * Fix crash on links that point to a non existant page
  * Make Document::renderHints return the correct render hints
  * Fix infinite loop when parsing LineAnnotation
  core:
  * Fix crash in the Splash renderer when T3 fonts are badly defined
  * Draw underlined Links correctly
  utils:
  * Fix two use after free bugs in HtmlOutputDev.cc
  build system:
  * Fix build on mingw32
  tests:
  * Distribute the glade file of pdf-inspector.
* Fri Jan 25 2008 maw@suse.de
- Update to version 0.6.3:
  + core:
  * Fix CVE-2007-4352, CVE-2007-5392 and CVE-2007-5393
  * Fix a crash on documents with wrong CCITTFaxStream
  * Fix a crash in the Cairo renderer with invalid embedded fonts
  * Fix a crash with invalid TrueType fonts
  * Check if font is inside the clip area before rendering
    it to a temporary bitmap in the Splash renderer. Fixes crashes
    on incorrect documents
  * Do not use exit(1) on DCTStream errors
  * Detect form fields at any depth level
  * Do not generate appearance stream for radio buttons that are
    not active
  * mingw fixes
  * Fix crash in extra debug code
  + glib frontend:
  * Make sure passwords are passed correctly to poppler core
  + Qt frontend:
  * Improved documentation
  * Fix crash on documents that specify an empty date
  + Misc build improvements
- Remove xpdf2-CVE-2007-4352.diff, xpdf2-CVE-2007-5392.diff,
  and xpdf2-CVE-2007-5393.diff, all of which have been upstreamed.
* Fri Jan 25 2008 stbinner@suse.de
- fix build on 10.2
* Mon Nov  5 2007 maw@suse.de
- Add xpdf2-CVE-2007-4352.diff, xpdf2-CVE-2007-5392.diff,
  and xpdf2-CVE-2007-5393.diff (#335637, CVE-2007-4352,
  CVE-2007-5392, and CVE-2007-5393).
* Wed Oct 31 2007 sbrabec@suse.cz
- Provide and obsolete poppler-doc (#338021).
* Tue Oct 23 2007 sbrabec@suse.cz
- Use split-provides. Obsoleting something another package provides
  creates a conflict between them.
* Tue Oct 23 2007 jpr@suse.de
- Updated to version 0.6.1:
  * Fix printing with different x and y scale
  * Fix crash when Form Fields array contains references to non
  existent objects
  * Fix crash in CairoOutputDev::drawMaskedImage()
  * Fix embedded file description not working on some cases
  * Fix printing issue with qt4
  * Avoid double free with qt4
  * Fix memory leak when dealing with embedded files in qt4
  * Fix build with --disable-cairo-output for glib
  * Do not return unknown field type for signature form fields for
  glib
  * Support automake-1.10
  * More compatible sh code in qt.m4
  * Fix build on Sun Studio compiler
- For libpoppler-qt3-devel, libpoppler-qt4-devel and
  libpoppler-glib-devel require libpoppler-devel not poppler-devel since
  for obsoletion reasons that is provided by those packages (#335567)
-Add gnome-common to the build requires to remove configure errors
* Thu Oct 11 2007 sbrabec@suse.cz
- Use less strict dependencies for shared libraries.
- poppler devel package names prepended by "lib".
- poppler-qt-devel renamed to libpoppler-qt3-devel
- Fixed poppler_spec-prepare.sh to not alter %%changes.
* Mon Oct  8 2007 sbrabec@suse.cz
- Updated to version 0.6:
  * CairoOutputDev fixes
  * Allow pdftoppm to read/write from stdin/stdout
  * API work on Qt4 frontend
  * Fix pdfimages produces inverted image for black & white image
  * Fix error on the NFKC text matching routine
  * Add support for word and line selections
  * Do not enforce %%%%EOF at the end of file
  * Pad zeroes instead of aborting when rendering 1-bit images
    and the stream is too short
  * Update glib bindings documentation
  * Merge xpdf 3.02 changes
  * Qt4 frontend is not marked anymore as unstable
  * Support for Sound objects
  * Support for Opening/Closing page actions
  * Support for page duration
  * Improve PS Tokenizer performance thanks
  * Various speed ups
  * Beginning of Interactive Form support
  * xpdfrc is no longer used for anything
  * Add AbiWord output device and pdftoabw program
  * Fix security issue MOAB-06-01-2007
  * Lots of bugs fixed
- Rename packages according to shared library naming policy.
- Make devel packages binding specific to deliver correct
  dependencies (#249436).
* Sat Mar 10 2007 dmueller@suse.de
- remove now broken .la files from devel package
  to fix build of all depending packages
* Mon Mar  5 2007 sbrabec@suse.cz
- Fixed devel dependencies (#249436).
- Removed some devel dependencies to force less to install.
* Mon Feb  5 2007 werner@suse.de
- Simplify usage of class UGooString
* Fri Jan 19 2007 maw@suse.de
- Add poppler-PageTree-depth-CVE-2007-0104.patch, fixing an
  infinite loop in page tree (#233133 and CVE-2007-0104).
* Mon Jan 15 2007 dmueller@suse.de
- don't build static libs
* Fri Jan 12 2007 dmueller@suse.de
- fix pedantic warnings in qt4 headers
* Tue Jan  2 2007 sbrabec@suse.cz
- Fixed qt detection (#229896).
- Fixed dependencies.
- Reverted poppler-qt3 back to poppler-qt (#229896).
* Fri Dec 29 2006 james@usr-local-bin.org
- New subpackage: poppler-qt4
- Rename poppler-qt to be poppler-qt3
* Sat Dec 23 2006 james@usr-local-bin.org
- Add wildcard to use QT3 and QT4 bindings
* Tue Dec 19 2006 sbrabec@suse.cz
- Spec file cleanup.
- Splitted poppler-doc from poppler.
* Thu Oct 26 2006 jhargadon@suse.de
- added --sysconfdir=/etc option to ./configure in the specfile
  as another part of the fix for bug #201739
* Wed Oct  4 2006 jhargadon@suse.de
- moved man pages to the poppler-tools subpackage [#201739]
* Wed Sep 27 2006 jhargadon@suse.de
- update to version 0.5.4
- Automatically read in CJK encoding files if they're installed
- Speed ups
- Patch from Dom Lachowicz to let the utils take input on stdin
- many bug fixes
* Mon Sep  4 2006 sbrabec@suse.cz
- Define conflict poppler-tools x xpdf-tools (#201739#c4).
* Thu Aug 31 2006 sbrabec@suse.cz
- Created poppler-tools providing xpdf-tools (#201739).
- Enabled parallel build.
* Fri Jul  7 2006 aj@suse.de
- Add back missing headers.
* Thu Jul  6 2006 gekker@suse.de
- Update to version 0.5.3
- Remove upstreamed patches
* Tue Jun 13 2006 gekker@suse.de
- Fix evince crasher when selecting text (#152780)
* Thu Mar 23 2006 sbrabec@suse.cz
- Display CJK with cairo correctly (Mandriva patch, #160230).
- Fixed devel dependencies.
* Tue Feb  7 2006 sbrabec@suse.cz
- Fixed SplashXPathScanner heap overflow (#141242, CVE-2006-0301).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 nadvornik@suse.cz
- updated to 0.4.4
- security patches merged upstream
* Mon Jan 16 2006 meissner@suse.de
- added -fno-strict-aliasing.
* Mon Jan 16 2006 meissner@suse.de
- use -fstack-protector.
* Wed Jan 11 2006 sbrabec@suse.cz
- Removed libpixman from neededforbuild.
* Thu Dec 15 2005 sbrabec@suse.cz
- Fixed more xpdf overflows and signed integer multiplications
  (Chris Evans, Martin Pitt, #137156).
* Wed Dec  7 2005 sbrabec@suse.cz
- Xpdf heap owerflow fixes (#137156, CAN-2005-3191, CAN-2005-3192,
  CAN-2005-3193).
* Mon Oct 24 2005 stbinner@suse.de
- remove remaining extra qualifications
* Tue Oct 18 2005 dmueller@suse.de
- fix extra qualifications in installed headers
* Fri Sep  2 2005 gekker@suse.de
- Update to version 0.4.2
- Fixes to work with new cairo version
- Required by evince update for GNOME 2.12
* Thu Aug 18 2005 gekker@suse.de
- Update to version 0.4.0
- Remove uptreamed patchs
* Thu Jul 21 2005 gekker@suse.de
- Update to version 0.3.3
* Mon Jun 27 2005 meissner@suse.de
- supply format attributes.
* Wed Jun  1 2005 sbrabec@suse.cz
-  Fixed pkgconfig file.
* Tue May 24 2005 sbrabec@suse.cz
- Updated to version 0.3.2.
* Mon May 23 2005 sbrabec@suse.cz
- Split poppler-glib to subpackage.
* Sun May 22 2005 aj@suse.de
- Fix build with GCC4.
* Mon May  9 2005 sbrabec@suse.cz
- New SuSE package, version 0.3.1.
